\name{Alfalfa}
\alias{Alfalfa}
\non_function{}
\title{Split-Plot Experiment on Varieties of Alfalfa}
\description{
  The \code{Alfalfa} data frame has 72 rows and 4 columns.
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{Variety}{
      a factor with levels
      \code{Cossack},
      \code{Ladak}, and 
      \code{Ranger} 
    }
    \item{Date}{
      a factor with levels
      \code{None} 
      \code{S1} 
      \code{S20} 
      \code{O7} 
    }
    \item{Block}{
      a factor with levels
      \code{1} 
      \code{2} 
      \code{3} 
      \code{4} 
      \code{5} 
      \code{6} 
    }
    \item{Yield}{
      a numeric vector
    }
  }
}
\details{
  These data are described in Snedecor and Cochran (1980) as
  an example of a split-plot design. The treatment structure used in the
  experiment was a 3\eqn{ x }{\times}4 full factorial, with three varieties of
  alfalfa and four dates of third cutting in 1943. The experimental
  units were arranged into six blocks, each subdivided into four plots.
  The varieties of alfalfa (\emph{Cossac}, \emph{Ladak}, and
  \emph{Ranger}) were assigned randomly to the blocks and the dates of
  third cutting (\emph{None}, \emph{S1}---September 1,
  \emph{S20}---September 20, and \emph{O7}---October 7) were randomly
  assigned to the plots.  All four dates were used on each block.
}
\source{
  Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
    and S-PLUS}, Springer, New York.  (Appendix A.1)

  Snedecor, G. W. and Cochran, W. G. (1980), \emph{Statistical Methods (7th
    ed)}, Iowa State University Press, Ames, IA
}
\examples{
data(Alfalfa)
}
\keyword{datasets}

\eof
\name{Assay}
\alias{Assay}
\non_function{}
\title{Bioassay on Cell Culture Plate}
\description{
    The \code{Assay} data frame has 60 rows and 4 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{Block}{
	    an ordered factor with levels
	    \code{2} < \code{1} identifying the block where the wells
	    are measured.
	}
	\item{sample}{
	    a factor with levels \code{a} to \code{f} identifying the
	    sample corresponding to the well.
	}
	\item{dilut}{
	    a factor with levels
	    \code{1} to \code{5}
	    indicating the dilution applied to the well
	}
	\item{logDens}{
	    a numeric vector of the log-optical density
	}
    }
}
\details{
    These data, courtesy of Rich Wolfe and David Lansky from Searle,
    Inc., come from a bioassay run on a 96-well cell culture plate.  The
    assay is performed using a split-block design.  The 8 rows on the
    plate are labeled A--H from top to bottom and the 12 columns on the
    plate are labeled 1--12 from left to right.  Only the central 60 wells
    of the plate are used for the bioassay (the intersection of rows B--G
    and columns 2--11).  There are two blocks in the design: Block 1
    contains columns 2--6 and Block 2 contains columns 7--11. Within each
    block, six samples are assigned randomly to rows and five (serial)
    dilutions are assigned randomly to columns. The response variable is
    the logarithm of the optical density. The cells are treated with a
    compound that they metabolize to produce the stain.  Only live cells
    can make the stain, so the optical density is a measure of the number
    of cells that are alive and healthy.}
\source{
   Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
     and S-PLUS}, Springer, New York. (Appendix A.2)
}
\examples{
data(Assay)
}
\keyword{datasets}

\eof
\name{BIC}
\docType{genericFunction}
\alias{BIC}
\alias{BIC,logLik-method}
\title{Bayesian Information Criterion}
\description{
  This generic function calculates the Bayesian information criterion,
  also known as Schwarz's Bayesian criterion (SBC), for one or several
  fitted model objects for which a log-likelihood value can be obtained,
  according to the formula \eqn{-2 \mbox{log-likelihood} + n_{par}
    \log(n_{obs})}{-2*log-likelihood + npar*log(nobs)}, where
  \eqn{n_{par}}{npar}  represents the
  number of parameters and \eqn{n_{obs}}{nobs} the number of
  observations in the fitted model. 
}
\usage{
BIC(object, \dots)
}
\arguments{
  \item{object}{An object of a suitable class for the BIC to be
    calculated - usually a \code{\link[base:logLik]{logLik}} object
    created by a call to the \code{\link[base:logLik]{logLik}} generic.
  }
  \item{\dots}{Some methods for this generic function may take
    additional, optional arguments.  At present none do.}
}
\value{
  if just one object is provided, returns a numeric value with the
  corresponding BIC; if more than one object are provided, returns a
  \code{data.frame} with rows corresponding to the objects and columns
  representing the number of parameters in the model (\code{df}) and the
  BIC.
}
\references{
  Schwarz, G. (1978) "Estimating the Dimension of a Model", Annals of
  Statistics, 6, 461-464.
}
%\author{}
%\note{}
\seealso{\code{\link[base:logLik]{logLik}}, \code{\link{AIC}}}
%\examples{}
\keyword{models}


\eof
\name{BodyWeight}
\alias{BodyWeight}
\non_function{}
\title{Rat weight over time for different diets}
\description{
    The \code{BodyWeight} data frame has 176 rows and 4 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{weight}{
	    a numeric vector giving the body weight of the rat (grams).
	}
	\item{Time}{
	    a numeric vector giving the time at which the measurement is
	    made (days).
	}
	\item{Rat}{
	    an ordered factor with levels \code{2} < \code{3} < \code{4}
	    < \code{1} < \code{8} < \code{5} < \code{6} < \code{7} <
	    \code{11} < \code{9} < \code{10} < \code{12} < \code{13} <
	    \code{15} < \code{14} < \code{16} identifying the rat whose
	    weight is measured.
	}
	\item{Diet}{
	    a factor with levels
	    \code{1} to \code{3} indicating the diet that the rat receives.
	}
    }
}
\details{
    Hand and Crowder (1996) describe data on the body weights of rats
    measured over 64 days.  These data also appear in Table 2.4 of
    Crowder and Hand (1990).  The body weights of the rats (in grams)
    are measured on day 1 and every seven days thereafter until day 64,
    with an extra measurement on day 44. The experiment started several
    weeks before ``day 1.''  There are three groups of rats, each on a
    different diet.
}
\source{
   Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
       and S-PLUS}, Springer, New York. (Appendix A.3)

   Crowder, M. and Hand, D. (1990), \emph{Analysis of Repeated
       Measures}, Chapman and Hall, London.

   Hand, D. and Crowder, M. (1996), \emph{Practical Longitudinal Data
       Analysis}, Chapman and Hall, London.
}
\examples{
data(BodyWeight)
}
\keyword{datasets}

\eof
\name{Cefamandole}
\alias{Cefamandole}
\non_function{}
\title{Pharmacokinetics of Cefamandole}
\description{
  The \code{Cefamandole} data frame has 84 rows and 3 columns.
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{Subject}{
      a factor giving the subject from which the sample was drawn.
    }
    \item{Time}{
      a numeric vector giving the time at which the sample was drawn
      (minutes post-injection).
    }
    \item{conc}{
      a numeric vector giving the observed plasma concentration of
      cefamandole (mcg/ml).
    }
  }
}
\details{
  Davidian and Giltinan (1995, 1.1, p. 2) describe data
  obtained during a pilot study to investigate the pharmacokinetics of
  the drug cefamandole. Plasma concentrations of the drug were measured
  on six healthy volunteers at 14 time points following an intraveneous
  dose of 15 mg/kg body weight of cefamandole.
}
\source{
  Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
    and S-PLUS}, Springer, New York.  (Appendix A.4)

  Davidian, M. and Giltinan, D. M. (1995), \emph{Nonlinear Models for
    Repeated Measurement Data},  Chapman and Hall, London.
}
\examples{
data(Cefamandole)
plot(Cefamandole)
#fm1 <- nlsList(SSbiexp, data = Cefamandole)
#summary(fm1)
}
\keyword{datasets}

\eof
\name{Chem97}
\alias{Chem97}
\docType{data}
\title{Scores on A-level Chemistry in 1997}
\description{
  Scores on the 1997 A-level Chemistry examination in Britain.  Students
  are grouped into schools within local education authories.  In
  addition some demographic and pre-test information is provided.
}
\usage{data(Chem97)}
\format{
  A data frame with 31022 observations on the following 8 variables.
  \describe{
    \item{lea}{Local Education Authority - a factor}
    \item{school}{School identifier - a factor}
    \item{student}{Student identifier - a factor}
    \item{score}{Point score on A-level Chemistry in 1997}
    \item{gender}{Student's gender}
    \item{age}{Age in month, centred at 222 months or 18.5 years}
    \item{gcsescore}{Average GCSE score of individual.}
    \item{gcsecnt}{Average GCSE score of individual, centered at mean.}
  }
}
\details{
  This data set is relatively large with 31,022 individuals in 2,280
  schools.  Note that while this is used, illustratively, to fit Normal
  response models, the distribution of the response is not well
  described by a Normal distribution.}
\source{
  \url{http://multilevel.ioe.ac.uk/softrev/chem97.html}

}
\references{
  Yang, M., Fielding, A. and Goldstein, H. (2002). Multilevel ordinal
  models for examination grades (submitted to \emph{Statistical Modelling}).
}
\examples{
data(Chem97)
str(Chem97)
summary(Chem97)
fm1 <- lme(score ~ 1, data = Chem97, random = ~ 1 | lea/school)
summary(fm1)
fm2 <- lme(score ~ gcsecnt, data = Chem97, random = ~ 1 | lea/school)
summary(fm2)
}
\keyword{datasets}

\eof
\name{Contraception}
\alias{Contraception}
\docType{data}
\title{Contraceptive use in Bangladesh}
\description{
  These data on the use of contraception by women in urban and rural
  areas come from the 1988 Bangladesh Fertility Survey.
}
\usage{data(Contraception)}
\format{
  A data frame with 1934 observations on the following 6 variables.
  \describe{
    \item{woman}{Identifying code for each woman - a factor}
    \item{district}{Identifying code for each district - a factor}
    \item{use}{Contraceptive use at time of survey}
    \item{livch}{Number of living children at time of survey - an
      ordered factor.  Levels are \code{0}, \code{1}, \code{2}, \code{3+}}
    \item{age}{Age of woman at time of survey (in years), centred around
      mean.}
    \item{urban}{Type of region of residence - a factor.  Levels are
      \code{urban} and \code{rural}}
  }
}
%\details{}
\source{
  \url{http://multilevel.ioe.ac.uk/softrev/bang.html}
}
\references{
  Steele, F., Diamond, I. And Amin, S. (1996). Immunization uptake in
  rural Bangladesh: a multilevel analysis. \emph{Journal of the Royal
    Statistical Society, Series A} (159): 289-299.
}
\examples{
data(Contraception)
str(Contraception)
summary(Contraception)
fm1 <- GLMM(use ~ urban+age+livch, family = binomial,
            data = Contraception, random = ~ 1|district)
summary(fm1)
fm2 <- GLMM(use ~ urban+age+livch, family = binomial,
            data = Contraception, random = ~ 1|district,
            method = "Laplace")
summary(fm2)
fm3 <- GLMM(use ~ urban+age+livch, family = binomial,
            data = Contraception, random = ~ urban|district)
summary(fm3)
}
\keyword{datasets}

\eof
\name{Dialyzer}
\alias{Dialyzer}
\non_function{}
\title{High-Flux Hemodialyzer}
\description{
    The \code{Dialyzer} data frame has 140 rows and 5 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{Subject}{
	    an ordered factor with levels
	    \code{10} < \code{8} < \code{2} < \code{6} < \code{3} <
	    \code{5} < \code{9} < \code{7} < \code{1} < \code{4} <
	    \code{17} < \code{20} < \code{11} < \code{12} < \code{16} <
	    \code{13} < \code{14} < \code{18} < \code{15} < \code{19}
	    giving the unique identifier for each subject
	}
	\item{QB}{
	    a factor with levels
	    \code{200} and 
	    \code{300} giving the bovine blood flow rate (dL/min).
	}
	\item{pressure}{
	    a numeric vector giving the transmembrane pressure (dmHg).
	}
	\item{rate}{
	    the hemodialyzer ultrafiltration rate (mL/hr).
	}
	\item{index}{
	    index of observation within subject---1 through 7.
	}
    }
}
\details{
    Vonesh and Carter (1992) describe data measured on high-flux
    hemodialyzers to assess their \emph{in vivo} ultrafiltration
    characteristics. The ultrafiltration rates (in mL/hr) of 20 high-flux
    dialyzers were measured at seven different transmembrane pressures (in
    dmHg). The \emph{in vitro} evaluation of the dialyzers used bovine
    blood at flow rates of either 200~dl/min or 300~dl/min. The data,
    are also analyzed in Littell, Milliken, Stroup, and Wolfinger (1996).
}
\source{
    Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
	and S-PLUS}, Springer, New York. (Appendix A.6)

    Vonesh, E. F. and Carter, R. L. (1992), Mixed-effects nonlinear
    regression for unbalanced repeated measures, \emph{Biometrics},
    \bold{48}, 1-18.

    Littell, R. C., Milliken, G. A., Stroup, W. W. and Wolfinger,
    R. D. (1996), \emph{SAS System for Mixed Models}, SAS Institute,
    Cary, NC.
}
\examples{
data(Dialyzer)
}
\keyword{datasets}

\eof
\name{Early}
\alias{Early}
\docType{data}
\title{Early childhood intervention study}
\description{
  Cognitive scores of infants in a study of early childhood
  intervention.  The 103 infants from low income African American
  families were divided into a treatment group (58
  infants) and a control group (45 infants).  Starting at 0.5 years of age
  the infants in the treatment group were exposed to an enriched environment.
  Each infant's cognitive score on an age-specific, normalized scale was
  recorded at ages 1, 1.5, and 2 years.
}
\usage{data(Early)}
\format{
  This \code{groupedData} object contains the following columns
  \describe{
    \item{id}{An ordered factor of the id number for each infant.}
    \item{cog}{A numeric cognitive score.}
    \item{age}{The age of the infant at the measurement.}
    \item{trt}{A factor with two levels, \code{"N"} and \code{"Y"},
      indicating if the infant is in the early childhood intervention
      program.}
    }
}
%\source{}
\references{
  Singer, Judith D. and Willett, John B. (2003), \emph{Applied
    Longitudinal Data Analysis}, Oxford University Press. (Ch. 3)
}
\examples{
data(Early)
str(Early)
}
\keyword{datasets}

\eof
\name{Earthquake}
\alias{Earthquake}
\non_function{}
\title{Earthquake Intensity}
\description{
    The \code{Earthquake} data frame has 182 rows and 5 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{Quake}{
	    an ordered factor with levels
	    \code{20} < \code{16} < \code{14} < \code{10} < \code{3} <
	    \code{8} < \code{23} < \code{22} < \code{6} < \code{13} <
	    \code{7} < \code{21} < \code{18} < \code{15} < \code{4} <
	    \code{12} < \code{19} < \code{5} < \code{9} < \code{1} <
	    \code{2} < \code{17} < \code{11} indicating the earthquake
	    on which the measurements were made.
	}
	\item{Richter}{
	    a numeric vector giving the intensity of the earthquake on
	    the Richter scale.
	}
	\item{distance}{
	    the distance from the seismological measuring station to the
	    epicenter of the earthquake (km).
	}
	\item{soil}{
	    a factor with levels \code{0} and \code{1} 
	    giving the soil condition at the measuring station, either
	    soil or rock. 
	}
	\item{accel}{
	    maximum horizontal acceleration observed (g).
	}
    }
}
\details{
    Measurements recorded at available seismometer locations for 23
    large earthquakes in western North America between 1940 and 1980.
    They were originally given in Joyner and Boore (1981); are
    mentioned in Brillinger (1987); and are analyzed in Davidian
    and Giltinan (1995).
}
\source{
    Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
	and S-PLUS}, Springer, New York.  (Appendix A.8)

    Davidian, M. and Giltinan, D. M. (1995), \emph{Nonlinear Models for
	Repeated Measurement Data},  Chapman and Hall, London.

    Joyner and Boor (1981), Peak horizontal acceleration and velocity from
    strong-motion records including records from the 1979 Imperial
    Valley, California, earthquake, \emph{Bulletin of the Seismological
	Society of America}, \bold{71}, 2011-2038.

    Brillinger, D. (1987), Comment on a paper by C. R. Rao,
    \emph{Statistical Science}, \bold{2}, 448-450.
}
\examples{
data(Earthquake)
}
\keyword{datasets}

\eof
\name{Exam}
\alias{Exam}
\docType{data}
\title{Exam scores from inner London}
\description{
  Exam scores of 4,059 students from 65 schools in Inner London.
}
\usage{data(Exam)}
\format{
  A data frame with 4059 observations on the following 9 variables.
  \describe{
    \item{school}{School ID - a factor.}
    \item{normexam}{Normalized exam score.}
    \item{schgend}{School gender - a factor.  Levels are \code{mixed},
      \code{boys}, and \code{girls}.}
    \item{schavg}{School average of intake score.}
    \item{vr}{Student level Verbal Reasoning (VR) score band at intake -
      a factor.  Levels are \code{bottom 25\%}, \code{mid 50\%}, and
      \code{top 25\%}.}
    \item{intake}{Band of student's intake score - a factor.
      Levels are \code{bottom 25\%}, \code{mid 50\%} and \code{top
	25\%}./}
    \item{standLRT}{Standardised LR test score.}
    \item{sex}{Sex of the student - levels are \code{F} and \code{M}.}
    \item{type}{School type - levels are \code{Mxd} and \code{Sngl}.}
    \item{student}{Student id (within school) - a factor}
  }
}
%\details{}
\source{
  \url{http://multilevel.ioe.ac.uk/softrev/exam.html}
}
\references{
  Goldstein, H., Rasbash, J., et al (1993). A multilevel analysis of
  school examination results. \emph{Oxford Review of Education} 19: 425-433 
}
\examples{
data(Exam)
str(Exam)
summary(Exam)
fm1 <- lme(normexam ~ standLRT + sex + schgend,
           data = Exam, random = ~ 1|school)
summary(fm1)
fm2 <- lme(normexam ~ standLRT*sex + schgend,
           data = Exam, random = ~ 1|school)
summary(fm2)
fm3 <- lme(normexam ~ standLRT*sex + schgend,
          data = Exam, random = ~ standLRT|school)
summary(fm3)
}
\keyword{datasets}

\eof
\name{Fatigue}
\alias{Fatigue}
\non_function{}
\title{Cracks caused by metal fatigue}
\description{
  The \code{Fatigue} data frame has 262 rows and 3 columns.
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{Path}{
      an ordered factor with levels
      \code{1} < \code{2} < \code{3} < \code{4} < \code{5} <
      \code{6} < \code{7} < \code{8} < \code{9} < \code{10} <
      \code{11} < \code{12} < \code{13} < \code{14} < \code{15} <
      \code{16} < \code{17} < \code{18} < \code{19} < \code{20} <
      \code{21} giving the test path (or test unit) number.  The
      order is in terms of increasing failure time or decreasing
      terminal crack length.
    }
    \item{cycles}{
      number of test cycles at which the measurement is made
      (millions of cycles).
    }
    \item{relLength}{
      relative crack length (dimensionless).
    }
  }
}
\details{
  These data are given in Lu and Meeker (1993) where they state
  ``We obtained the data in Table 1 visually from figure 4.5.2 on page 242
  of Bogdanoff and Kozin (1985).''
  The data represent the growth of cracks in metal for 21 test units.
  An initial notch of length 0.90 inches was made on each unit which then
  was subjected to several thousand test cycles.  After every 10,000
  test cycles the crack length was measured.  Testing was stopped if the
  crack length exceeded 1.60 inches, defined as a failure, or at 120,000
  cycles.
}
\source{
  Lu, C. Joseph , and Meeker, William Q. (1993), Using degradation
  measures to estimate a time-to-failure distribution,
  \emph{Technometrics}, \bold{35}, 161-174 
}
\examples{
data(Fatigue)
}
\keyword{datasets}

\eof
\name{GLMM-class}
\docType{class}
\alias{GLMM-class}
\alias{coef,GLMM-method}
\alias{deviance,GLMM-method}
\alias{fixef,GLMM-method}
\alias{logLik,GLMM-method}
\alias{ranef,GLMM-method}
\alias{show,GLMM-method}
\alias{summary,GLMM-method}

\title{Class "GLMM"}
\description{A fitted generalized linear mixed model.}
\section{Objects from the Class}{
    Objects are usually created by calls to the constructor function
  \code{GLMM}.  They also can be created by calls of the form
  \code{new("GLMM", ...)}.
}
\section{Slots}{
  \describe{
    \item{\code{family}:}{The family of functions
      defining the generalized linear model.  See
      \code{\link[stats]{family}} for details.}
    \item{\code{logLik}:}{the \code{"numeric"} value of the log-likelihood.}
    \item{\code{fixef}:}{A \code{"numeric"} vector of fixed-effects
      parameters.}
    \item{\code{call}:}{A copy of the function call that created the object.}
    \item{\code{facs}:}{A \code{list} of (possibly reordered) grouping
      factors associated with the random effects.}
    \item{\code{x}:}{If the optional argument \code{x} to
      \code{lme} is \code{TRUE}, a \code{list} of model matrices
      associated with the random effects, and the fixed effects with the
      response appended. Otherwise, an empty list.}
    \item{\code{model}:}{The model frame (of class \code{"data.frame"})
      for the model or, if the optional argument
      \code{model} to \code{lme} is \code{FALSE}, an empty frame.}
    \item{\code{REML}:}{A \code{"logical"} indicator of the model having
      been fit according to the REML criterion.}
    \item{\code{rep}:}{An \code{"ssclme"} object representing the fitted
      model.}
    \item{\code{fitted}:}{A \code{"numeric"} vector of fitted values.}
    \item{\code{residuals}:}{A \code{"numeric"} vector of raw residuals.}
  }
}
\section{Extends}{
Class \code{"lme"}, directly.
}
\section{Methods}{
  \describe{
    \item{VarCorr}{\code{signature(x = "GLMM")}: Extract the variances,
      standard deviations, and correlations of the random effects.}
    \item{anova}{\code{signature(object = "GLMM")}: Perform an analysis
      of variance.}
    \item{coef}{\code{signature(object = "GLMM")}: Extract the parameters
      that determine the relative precision matrices. The optional
      argument \code{unconst} determines if the constrained or
      unconstrained parameterization is used.}
    \item{deviance}{\code{signature(object = "GLMM")}: Extract the
      deviance as a numeric scalar.  The optional argument \code{REML}
      determines if the REML or ML criterion is used.}
    \item{fitted}{\code{signature(object = "GLMM")}: Extract the fitted
      values as a numeric vector.}
    \item{fixef}{\code{signature(object = "GLMM")}: Extract the fixed
      effects coefficients as a named numeric vector }
    \item{formula}{\code{signature(x = "GLMM")}: Extract the formula of
      the response and the fixed effects.}
    \item{logLik}{\code{signature(object = "GLMM")}: Extract the
      log-likelihood.}
    \item{plot}{\code{signature(x = "GLMM")}:}
    \item{ranef}{\code{signature(object = "GLMM")}: Extact the random
      effects as a named list of numeric matrices.}
    \item{residuals}{\code{signature(object = "GLMM")}: Extract the
      residuals as a numeric vector.}
    \item{show}{\code{signature(object = "GLMM")}: Print a concise
      description of the object.}
    \item{summary}{\code{signature(object = "GLMM")}: Create a summary
      object of class \code{"summary.lme"}.}
    \item{update}{\code{signature(object = "GLMM")}: Create an updated
      fitted model.}
    \item{vcov}{\code{signature(object = "GLMM")}: Extract the variances
      and covariances of the fixed-effects parameter estimates.}
  }
}
\details{Many methods for the \code{"GLMM"} class simply recall the
  generic on \code{as(object, "lme")} which, in turn, often calls the
    generic on the \code{"rep"} component of the first argument.  Thus the
    methods actually are applied to an object of the \code{"lme"} or
    \code{"ssclme"} class.}
\seealso{
  \code{\link{GLMM}}, \code{\link{lme-class}},
  \code{\link[Matrix]{ssclme-class}}
}
\keyword{classes}

\eof
\name{GLMM}
\alias{GLMM}
\alias{GLMM,ANY,ANY,ANY,formula-method}
\alias{GLMM,formula,ANY,ANY,list-method}
\alias{GLMM,formula,ANY,groupedData,list-method}
\alias{GLMM,formula,ANY,groupedData,missing-method}
\alias{GLMM,missing,ANY,ANY,ANY-method}
\title{
Fit Generalized Linear Mixed Models via PQL
}
\description{
Fit a GLMM model with multivariate normal random effects, using
Penalized Quasi-Likelihood.
}
\synopsis{
GLMM(formula, family, data, random, method = c("PQL", "Laplace"),
     control = list(), subset, weights, na.action, offset,
     model = TRUE, x = FALSE, y = FALSE, \dots)
}
\usage{
GLMM(formula, family, data, random, \dots)
}
\arguments{
  \item{formula}{
    a two-sided linear model formula giving fixed-effects part of the model.
  }
  \item{family}{
    a GLM family, see \code{\link[stats]{glm}}.
  }
  \item{data}{
    an optional data frame used as the first place to find
    variables in the formulae.
  }
  \item{random}{
    A formula or named list of formulae describing the random effects.
  }
  \item{\dots}{
    Optional further arguments such as \code{subset} and \code{na.action}.
  }
}
\details{
  Additional arguments, some of them standard in model-fitting
  functions, can be passed to \code{GLMM}.
  \describe{
    \item{subset}{an optional expression indicating the subset of the rows of
      \code{data} that should be used in the fit. This can be a logical
      vector, or a numeric vector indicating which observation numbers are
      to be included, or a  character  vector of the row names to be
      included.  All observations are included by default.}
    %  \item{niter}{
    %    maximum number of PQL iterations.  Default is 20.
    %  }
    \item{method}{
      character: Estimation method to be used.  Possible values are
      \code{"PQL"}, the default, or \code{"Laplace"}.
      \code{"PQL"} provides penalized quasi-likelihood estimates.
      \code{"Laplace"} provides PQL
      estimation followed by optimization of the second-order Laplacian
      approximation to the marginal log-likelihood.
    }
    \item{na.action}{a function that indicates what should happen when the
      data contain \code{NA}s.  The default action (\code{na.fail}) causes
      \code{lme} to print an error message and terminate if there are any
      incomplete observations.}
    \item{control}{
      an optional argument to be passed to \code{lme}.
    }
    \item{model, x}{logicals.  If \code{TRUE} the corresponding
      components of the fit (the model frame, the model matrices)
      are returned.}
  }
}
\value{
  An object of class \code{"lme"}: see \code{\link[Matrix]{ssclme-class}}.
}
\references{
Schall, R. (1991) Estimation in generalized linear models with
random effects.
\emph{Biometrika}
\bold{78}, 719--727.


Breslow, N. E. and Clayton, D. G. (1993) Approximate inference in
generalized linear mixed models.
\emph{Journal of the American Statistical Association}
\bold{88}, 9--25.


Wolfinger, R. and O'Connell, M. (1993) Generalized linear mixed models: a
pseudo-likelihood approach.
\emph{Journal of Statistical Computation and Simulation}
\bold{48}, 233--243.
}
\seealso{
  \code{\link{lme}}
}
\examples{
data(guImmun)
fm1 <-
    GLMM(immun ~ kid2p + mom25p + ord + ethn +
                 momEd + husEd + momWork + rural + pcInd81,
         family = binomial, data = guImmun, random = ~1|comm)
summary(fm1)
}
\keyword{models}

\eof
\name{Gasoline}
\alias{Gasoline}
\non_function{}
\title{Refinery yield of gasoline}
\description{
  The \code{Gasoline} data frame has 32 rows and 6 columns.
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{yield}{
      a numeric vector giving the percentage of crude oil converted to
      gasoline after distillation and fractionation
    }
    \item{endpoint}{
        a numeric vector giving the temperature (degrees F) at which all
	the gasoline is vaporized
    }
    \item{Sample}{
      an ordered factor giving the inferred crude oil sample number
    }
    \item{API}{
      a numeric vector giving the crude oil gravity (degrees API)
    }
    \item{vapor}{
	a numeric vector giving the vapor pressure of the crude oil
	\eqn{(\mathrm{lbf}/\mathrm{in}^2)}{(lbf/in^2)}
    }
    \item{ASTM}{
      a numeric vector giving the crude oil 10\% point ASTM---the
      temperature at which 10\% of the crude oil has become vapor. 
    }
  }
}
\details{
  Prater (1955) provides data on crude oil properties and
  gasoline yields.  Atkinson (1985)
  uses these data to illustrate the use of diagnostics in multiple
  regression analysis.  Three of the covariates---\textsf{API},
  \textsf{vapor}, and \textsf{ASTM}---measure characteristics of the
  crude oil used to produce the gasoline.  The other covariate ---
  \textsf{endpoint}---is a characteristic of the refining process.
  Daniel and Wood (1980) notice that the covariates characterizing
  the crude oil occur in only ten distinct groups and conclude that the
  data represent responses measured on ten different crude oil samples.
}
\source{
  Prater, N. H. (1955), Estimate gasoline yields from crudes,
  \emph{Petroleum Refiner}, \bold{35} (5).

  Atkinson, A. C. (1985), \emph{Plots, Transformations, and
    Regression}, Oxford Press, New York.

  Daniel, C. and Wood, F. S. (1980), \emph{Fitting Equations to Data},
  Wiley, New York

  Venables, W. N. and Ripley, B. D. (1999) \emph{Modern Applied
    Statistics with S-PLUS (3rd ed)}, Springer, New York.
}
\examples{
data(Gasoline)
}
\keyword{datasets}

\eof
\name{Gcsemv}
\alias{Gcsemv}
\docType{data}
\title{GCSE exam score}
\description{
  The GCSE exam scores on a science subject. Two components of the exam
  were chosen as outcome variables: written paper and course work. There
  are 1,905 students from 73 schools in England.
}
\usage{data(Gcsemv)}
\format{
  A data frame with 1905 observations on the following 5 variables.
  \describe{
    \item{school}{School ID - a factor}
    \item{student}{Student ID - a factor}
    \item{gender}{Gender of student}
    \item{written}{Total score on written paper}
    \item{course}{Total score on coursework paper}
  }
}
%\details{}
\source{
  \url{http://multilevel.ioe.ac.uk/softrev/gcsemv.html}
}
\references{
  Multivariate response models. (2000). In Rasbash, J., et al, \emph{A
    user's guide to MLwiN}, Institute of Education, University of
  London.
}
\examples{
data(Gcsemv)
str(Gcsemv)
}
\keyword{datasets}

\eof
\name{Glucose}
\alias{Glucose}
\non_function{}
\title{Glucose levels over time}
\description{
    The \code{Glucose} data frame has 378 rows and 4 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{Subject}{
	    an ordered factor with levels
	    \code{6} < \code{2} < \code{3} < \code{5} < \code{1} < \code{4}
	}
	\item{Time}{
	    a numeric vector
	}
	\item{conc}{
	    a numeric vector of glucose levels
	}
	\item{Meal}{
	    an ordered factor with levels
	    \code{2am} < \code{6am} < \code{10am} < \code{2pm} < \code{6pm} < \code{10pm}
	}
    }
}
\source{
    Hand, D. and Crowder, M. (1996), \emph{Practical Longitudinal Data
	Analysis}, Chapman and Hall, London.
}
\examples{
data(Glucose)
}
\keyword{datasets}

\eof
\name{Glucose2}
\alias{Glucose2}
\non_function{}
\title{Glucose Levels Following Alcohol Ingestion}
\description{
  The \code{Glucose2} data frame has 196 rows and 4 columns.
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{Subject}{
      a factor with levels
      \code{1} to \code{7} identifying the subject whose glucose
      level is measured. 
    }
    \item{Date}{
      a factor with levels
      \code{1} 
      \code{2}
      indicating the occasion in which the experiment was conducted.
    }
    \item{Time}{
      a numeric vector giving the time since alcohol ingestion (in min/10).
    }
    \item{glucose}{
      a numeric vector giving the blood glucose level (in mg/dl).
    }
  }
}
\details{
  Hand and Crowder (Table A.14, pp. 180-181, 1996) describe data on
  the blood glucose levels measured at 14 time points over 5 hours for 7
  volunteers who took alcohol at time 0. The same experiment was
  repeated on a second date with the same subjects but with a dietary
  additive used for all subjects.
}
\source{
  Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
    and S-PLUS}, Springer, New York.  (Appendix A.10)

  Hand, D. and Crowder, M. (1996), \emph{Practical Longitudinal Data
    Analysis}, Chapman and Hall, London.
}
\examples{
data(Glucose2)
}
\keyword{datasets}

\eof
\name{Gun}
\alias{Gun}
\non_function{}
\title{Methods for firing naval guns}
\description{
  The \code{Gun} data frame has 36 rows and 4 columns.
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{rounds}{
      a numeric vector
    }
    \item{Method}{
      a factor with levels
      \code{M1} 
      \code{M2} 
    }
    \item{Team}{
      an ordered factor with levels
      \code{T1S} < \code{T3S} < \code{T2S} < \code{T1A} <
      \code{T2A} < \code{T3A} < \code{T1H} < \code{T3H} <
      \code{T2H}
    }
    \item{Physique}{
      an ordered factor with levels
      \code{Slight} < \code{Average} < \code{Heavy}
    }
  }
}
\details{
  Hicks (p.180, 1993) reports data from an experiment on
  methods for firing naval guns. Gunners of three different physiques
  (slight, average, and heavy) tested two firing methods. Both methods
  were tested twice by each of nine teams of three gunners with
  identical physique. The response was the number of rounds fired per
  minute.}
\source{
  Hicks, C. R. (1993), \emph{Fundamental Concepts in the Design of
    Experiments (4th ed)}, Harcourt Brace, New York.
}
\examples{
data(Gun)
}
\keyword{datasets}

\eof
\name{Hsb82}
\alias{Hsb82}
\docType{data}
\title{High School and Beyond - 1982}
\description{
  Data from the 1982 study ``High School and Beyond''.
}
\usage{data(Hsb82)}
\format{
  A data frame with 7185 observations on students including the
  following 8 variables.
  \describe{
    \item{school}{an ordered factor designating the school that the
      student attends.}
    \item{minrty}{a factor with levels}
    \item{sx}{a factor with levels \code{Male} and \code{Female}}
    \item{ses}{a numeric vector of socio-economic scores}
    \item{mAch}{a numeric vector of Mathematics achievement scores}
    \item{meanses}{a numeric vector of mean \code{ses} for the school}
    \item{sector}{a factor with levels \code{Public} and \code{Catholic}}
    \item{cses}{a numeric vector of centered \code{ses} values where the
    centering is with respect to the \code{meanses} for the school.}
  }
}
\details{
  Each row in this data frame contains the data for one student.
}
%\source{}
\references{
  Raudenbush, Stephen and Bryk, Anthony (2002), \emph{Hierarchical
    Linear Models: Applications and Data Analysis Methods}, Sage
  (chapter 4).
}
\examples{
data(Hsb82)
summary(Hsb82)
}
\keyword{datasets}

\eof
\name{IGF}
\alias{IGF}
\non_function{}
\title{Radioimmunoassay of IGF-I Protein}
\description{
    The \code{IGF} data frame has 237 rows and 3 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{Lot}{
	    an ordered factor giving the radioactive tracer lot.
	}
	\item{age}{
	    a numeric vector giving the age (in days) of the radioactive
	    tracer.
	}
	\item{conc}{
	    a numeric vector giving the estimated concentration of IGF-I
	    protein (ng/ml)
	}
    }
}
\details{
    Davidian and Giltinan (1995) describe data obtained during quality
    control radioimmunoassays for ten different lots of radioactive
    tracer used to calibrate the Insulin-like Growth Factor (IGF-I)
    protein concentration measurements. 
}
\source{
    Davidian, M. and Giltinan, D. M. (1995), \emph{Nonlinear Models for
	Repeated Measurement Data},  Chapman and Hall, London.
    
    Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
	and S-PLUS}, Springer, New York.  (Appendix A.11)
}
\examples{
data(IGF)
}
\keyword{datasets}

\eof
\name{Machines}
\alias{Machines}
\non_function{}
\title{Productivity Scores for Machines and Workers}
\description{
  The \code{Machines} data frame has 54 rows and 3 columns.
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{Worker}{
      an ordered factor giving the unique identifier for the worker.
    }
    \item{Machine}{
      a factor with levels
      \code{A}, 
      \code{B}, and 
      \code{C} identifying the machine brand.
    }
    \item{score}{
      a productivity score.
    }
  }
}
\details{
  Data on an experiment to compare three brands of machines used in an
  industrial process are presented in Milliken and Johnson (p. 285,
  1992). Six workers were chosen randomly among the
  employees of a factory to operate each machine three times. The
  response is an overall productivity score taking into account the
  number and quality of components produced.}
\source{
  Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models
    in S and S-PLUS}, Springer, New York.  (Appendix A.14)

  Milliken, G. A. and Johnson, D. E. (1992), \emph{Analysis of Messy Data,
    Volume I: Designed Experiments}, Chapman and Hall, London.
}
\examples{
data(Machines)
}
\keyword{datasets}

\eof
\name{MathAchSchool}
\alias{MathAchSchool}
\non_function{}
\title{School demographic data for MathAchieve}
\description{
    The \code{MathAchSchool} data frame has 160 rows and 7 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{School}{
	    a factor giving the school on which the measurement is made.
	}
	\item{Size}{
	    a numeric vector giving the number of students in the school
	}
	\item{Sector}{
	    a factor with levels
	    \code{Public} 
	    \code{Catholic} 
	}
	\item{PRACAD}{
	    a numeric vector giving the percentage of students on the
	    academic track
	}
	\item{DISCLIM}{
	    a numeric vector measuring the discrimination climate
	}
	\item{HIMINTY}{
	    a factor with levels
	    \code{0} 
	    \code{1} 
	}
	\item{MEANSES}{
	    a numeric vector giving the mean SES score.
	}
    }
}
\details{
  These variables give the school-level demographic data to accompany
  the \code{MathAchieve} data.
}
\source{
}
\examples{
data(MathAchSchool)
}
\keyword{datasets}

\eof
\name{MathAchieve}
\alias{MathAchieve}
\non_function{}
\title{Mathematics achievement scores}
\description{
    The \code{MathAchieve} data frame has 7185 rows and 6 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{School}{
	    an ordered factor identifying the school that the student attends
	}
	\item{Minority}{
	    a factor with levels
	    \code{No} 
	    \code{Yes}
	    indicating if the student is a member of a minority racial group.
	}
	\item{Sex}{
	    a factor with levels
	    \code{Male} 
	    \code{Female} 
	}
	\item{SES}{
	    a numeric vector of socio-economic status.
	}
	\item{MathAch}{
	    a numeric vector of mathematics achievement scores.
	}
	\item{MEANSES}{
	    a numeric vector of the mean SES for the school.
	}
    }
}
\details{
  Each row in this data frame contains the data for one student.
}
\source{
}
\examples{
data(MathAchieve)
}
\keyword{datasets}

\eof
\name{Meat}
\alias{Meat}
\non_function{}
\title{Tenderness of meat}
\description{
  The \code{Meat} data frame has 30 rows and 4 columns.
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{Storage}{
      an ordered factor specifying the storage treatment - 1 (0
      days), 2 (1 day),  3 (2 days), 4 (4 days), 5 (9 days), and 6
      (18 days)
    }
    \item{score}{
      a numeric vector giving the tenderness score of beef roast.
    }
    \item{Block}{
      an ordered factor identifying the muscle from which the
      roast was extracted with levels 
      \code{II} < \code{V} < \code{I} < \code{III} < \code{IV}
    }
    \item{Pair}{
      an ordered factor giving the unique identifier for each pair
      of beef roasts with levels \code{II-1} < \dots{} < \code{IV-1}
    }
  }
}
\details{
  Cochran and Cox (section 11.51, 1957) describe data from an
  experiment conducted at Iowa State College (Paul, 1943) to
  compare the effects of length of cold storage on the tenderness of
  beef roasts.  Six storage periods ranging from 0 to 18 days were used.
  Thirty roasts were scored by four judges on a scale from 0 to 10, with
  the score increasing with tenderness. The response was the sum of all
  four scores. Left and right roasts from the same animal were grouped
  into pairs, which were further grouped into five blocks, according to
  the muscle from which they were extracted. Different storage periods
  were applied to each roast within a pair according to a balanced
  incomplete block design.}
\source{
  Cochran, W. G. and Cox, G. M. (1957), \emph{Experimental Designs},
  Wiley, New York.
}
\examples{
data(Meat)
}
\keyword{datasets}

\eof
\name{Milk}
\alias{Milk}
\non_function{}
\title{Protein content of cows' milk}
\description{
    The \code{Milk} data frame has 1337 rows and 4 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{protein}{
	    a numeric vector giving the protein content of the milk.
	}
	\item{Time}{
	    a numeric vector giving the time since calving (weeks).
	}
	\item{Cow}{
	    an ordered factor giving a unique identifier for each cow.
	}
	\item{Diet}{
	    a factor with levels
	    \code{barley}, 
	    \code{barley+lupins}, and 
	    \code{lupins} identifying the diet for each cow.
	}
    }
}
\details{
    Diggle, Liang, and Zeger (1994) describe data on the protein content
    of cows' milk in the weeks following calving.  The cattle are grouped
    according to whether they are fed a diet with barley alone, with
    barley and lupins, or with lupins alone. 
}
\source{
     Diggle, Peter J., Liang, Kung-Yee and Zeger, Scott L. (1994),
     \emph{Analysis of longitudinal data}, Oxford University Press,
     Oxford.
}
\examples{
data(Milk)
}
\keyword{datasets}

\eof
\name{Mmmec}
\alias{Mmmec}
\docType{data}
\title{Malignant melanoma deaths in Europe}
\description{
  Malignant Melanoma Mortality in the European Community associated with
  the impact of UV radiation exposure.
}
\usage{data(Mmmec)}
\format{
  A data frame with 354 observations on the following 6 variables.
  \describe{
    \item{nation}{a factor with levels \code{Belgium}, \code{W.Germany},
      \code{Denmark}, \code{France}, \code{UK}, \code{Italy}, \code{Ireland},
      \code{Luxembourg}, and \code{Netherlands}}
    \item{region}{Region ID - a factor.}
    \item{county}{County ID - a factor.}
    \item{deaths}{Number of male deaths due to MM during 1971--1980}
    \item{expected}{Number of expected deaths.}
    \item{uvb}{Centered measure of the UVB dose reaching the earth's
      surface in each county.}
  }
}
%\details{}
\source{
  \url{http://multilevel.ioe.ac.uk/softrev/mmmec.html}
}
\references{
  Langford, I.H., Bentham, G. and McDonald, A. 1998: Multilevel
  modelling of geographically aggregated health data: a case study on
  malignant melanoma mortality and UV exposure in the European
  community. \emph{Statistics in Medicine} 17: 41-58.
}
\examples{
data(Mmmec)
str(Mmmec)
summary(Mmmec)
fm1 <- GLMM(deaths ~ offset(log(expected)) + uvb,
 family = poisson, data = Mmmec, random = ~ 1 | region,
 niter = 25)
summary(fm1)
}
\keyword{datasets}

\eof
\name{Muscle}
\alias{Muscle}
\non_function{}
\title{Contraction of heart muscle sections}
\description{
    The \code{Muscle} data frame has 60 rows and 3 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{Strip}{
	    an ordered factor indicating the strip of muscle being measured.
	}
	\item{conc}{
	    a numeric vector giving the concentration of CaCl2
	}
	\item{length}{
	    a numeric vector giving the shortening ofthe heart muscle strip.
	}
    }
}
\details{
    Baumann and Waldvogel (1963) describe data on the shortening of heart
    muscle strips dipped in a CaCl$_2$ solution.  The muscle strips are
    taken from the left auricle of a rat's heart.}
\source{
    Baumann, F. and Waldvogel, F. (1963), La restitution pastsystolique
    de la contraction de l'oreillette gauche du rat. Effets de divers
    ions et de l'acetylcholine, \emph{Helvetica Physiologica Acta},
    \bold{21}.
}
\examples{
data(Muscle)
}
\keyword{datasets}

\eof
\name{Names}
\docType{genericFunction}
\alias{Names}
\alias{Names<-}
\alias{Names-methods}
\alias{Names<--methods}
\alias{Names,ANY-method}
\alias{Names<-,ANY-method}
\title{Extract or assign Names}
\description{
  Generic functions to extract or assign names of an object, usually an
  object of a class that inherits from the \code{pdMat} class.  This
  function is for back-compatibility only.
}
\usage{
Names(object, ...)
Names(object) <- value
}
\arguments{
  \item{object}{An object with names - usually an object that inherits
    from the \code{pdMat} class.}
  \item{value}{A character vector of the same length as \code{Names(object)}}
  \item{\dots}{Some methods for this generic function may use
    additional, optional arguments.}
}
\value{
  The names assigned to \code{object}.
}
\author{Douglas Bates \email{bates@stat.wisc.edu} and
  Saikat DebRoy \email{saikat@stat.wisc.edu}}
\seealso{\code{\link{names}}, \code{\link{names<-}}}
\examples{
}
\keyword{attribute}


\eof
\name{Nitrendipene}
\alias{Nitrendipene}
\non_function{}
\title{Assay of nitrendipene}
\description{
    The \code{Nitrendipene} data frame has 89 rows and 4 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{activity}{
	    a numeric vector
	}
	\item{NIF}{
	    a numeric vector
	}
	\item{Tissue}{
	    an ordered factor with levels
	    \code{2} < \code{1} < \code{3} < \code{4}
	}
	\item{log.NIF}{
	    a numeric vector
	}
    }
}
\details{

}
\source{
  Bates, D. M. and Watts, D. G. (1988), \emph{Nonlinear Regression
    Analysis and Its Applications}, Wiley, New York.
}
\examples{
data(Nitrendipene)
}
\keyword{datasets}

\eof
\name{Oats}
\alias{Oats}
\non_function{}
\title{Split-plot Experiment on Varieties of Oats}
\description{
  The \code{Oats} data frame has 72 rows and 4 columns.
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{Block}{
      an ordered factor with levels
      \code{VI} < \code{V} < \code{III} < \code{IV} < \code{II} < \code{I}
    }
    \item{Variety}{
      a factor with levels
      \code{Golden Rain} 
      \code{Marvellous} 
      \code{Victory} 
    }
    \item{nitro}{
      a numeric vector
    }
    \item{yield}{
      a numeric vector
    }
  }
}
\details{
  These data have been introduced by Yates (1935) as an
  example of a split-plot design. The treatment structure used in the
  experiment was a 3$\times$4 full factorial, with three varieties of
  oats and four concentrations of nitrogen. The experimental units were
  arranged into six blocks, each with three whole-plots subdivided into
  four subplots. The varieties of oats were assigned randomly to the
  whole-plots and the concentrations of nitrogen to the subplots.  All
  four concentrations of nitrogen were used on each whole-plot.
}
\source{
  Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
    and S-PLUS}, Springer, New York.  (Appendix A.15)

  Venables, W. N. and Ripley, B. D. (1999) \emph{Modern Applied
    Statistics with S-PLUS (3rd ed)}, Springer, New York.
}
\examples{
data(Oats)
}
\keyword{datasets}

\eof
\name{Orthodont}
\alias{Orthodont}
\non_function{}
\title{Growth curve data on an orthdontic measurement}
\description{
  The \code{Orthodont} data frame has 108 rows and 4 columns of the
  change in an orthdontic measurement over time for several young subjects.
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{distance}{
      a numeric vector of distances from the pituitary to the
      pterygomaxillary fissure (mm).  These distances are measured
      on x-ray images of the skull.
    }
    \item{age}{
      a numeric vector of ages of the subject (yr).
    }
    \item{Subject}{
      an ordered factor indicating the subject on which the
      measurement was made.  The levels are labelled \code{M01}
      to \code{M16} for the males and \code{F01} to \code{F13} for
      the females.  The ordering is by increasing average distance
      within sex.
    }
    \item{Sex}{
      a factor with levels
      \code{Male} and
      \code{Female} 
    }
  }
}
\details{
  Investigators at the University of North Carolina Dental School
  followed the growth of 27 children (16 males, 11 females) from age 8
  until age 14.  Every two years they measured the distance between the
  pituitary and the pterygomaxillary fissure, two points that are easily
  identified on x-ray exposures of the side of the head.
}
\source{
  Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
    and S-PLUS}, Springer, New York.  (Appendix A.17)

  Potthoff, R. F. and Roy,  S. N. (1964), ``A generalized multivariate
  analysis of variance model useful especially for growth curve
  problems'', \emph{Biometrika}, \bold{51}, 313--326.
}
\examples{
data(Orthodont)
formula(Orthodont)
plot(Orthodont)
}
\keyword{datasets}

\eof
\name{Ovary}
\alias{Ovary}
\non_function{}
\title{Counts of Ovarian Follicles}
\description{
  The \code{Ovary} data frame has 308 rows and 3 columns.
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{Mare}{
      an ordered factor indicating the mare on which the
      measurement is made.
    }
    \item{Time}{
      time in the estrus cycle.  The data were recorded daily from 3
      days before ovulation until 3 days after the next ovulation. The
      measurement times for each mare are scaled so that the ovulations for
      each mare occur at times 0 and 1.
    }
    \item{follicles}{
      the number of ovarian follicles greater than 10 mm in diameter.
    }
  }
}
\details{
  Pierson and Ginther (1987) report on a study of the number of large
  ovarian follicles detected in different mares at several times in
  their estrus cycles.
}
\source{
  Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
    and S-PLUS}, Springer, New York.  (Appendix A.18)

  Pierson, R. A. and Ginther, O. J. (1987), Follicular population
  dynamics during the estrus cycle of the mare, \emph{Animal
    Reproduction Science}, \bold{14}, 219-231.
}
\examples{
data(Ovary)
}
\keyword{datasets}

\eof
\name{Oxboys}
\alias{Oxboys}
\non_function{}
\title{Heights of Boys in Oxford}
\description{
  The \code{Oxboys} data frame has 234 rows and 4 columns.
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{Subject}{
      an ordered factor giving a unique identifier for each boy in
      the experiment
    }
    \item{age}{
      a numeric vector giving the standardized age (dimensionless)
    }
    \item{height}{
      a numeric vector giving the height of the boy (cm)
    }
    \item{Occasion}{
      an ordered factor - the result of converting \code{age} from a
      continuous variable to a count so these slightly unbalanced
      data can be analyzed as balanced.
    }
  }
}
\details{
  These data are described in Goldstein (1987) as data on the
  height of a selection of boys from Oxford, England versus a
  standardized age.
}
\source{
  Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in
    S and S-PLUS}, Springer, New York.  (Appendix A.19)
}
\examples{
data(Oxboys)
}
\keyword{datasets}

\eof
\name{Oxide}
\alias{Oxide}
\non_function{}
\title{Variability in Semiconductor Manufacturing}
\description{
  The \code{Oxide} data frame has 72 rows and 5 columns.
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{Source}{
      a factor with levels
      \code{1} and
      \code{2} 
    }
    \item{Lot}{
      a factor giving a unique identifier for each lot.
    }
    \item{Wafer}{
      a factor giving a unique identifier for each wafer within a lot.
    }
    \item{Site}{
      a factor with levels
      \code{1}, 
      \code{2}, and 
      \code{3} 
    }
    \item{Thickness}{
      a numeric vector giving the thickness of the oxide layer.
    }
  }
}
\details{
  These data are described in Littell et al. (1996, p. 155) as coming
  ``from a passive data collection study in the semiconductor industry
  where the objective is to estimate the variance components to
  determine the assignable causes of the observed variability.'' The
  observed response is the thickness of the oxide layer on silicon
  wafers, measured at three different sites of each of three wafers
  selected from each of eight lots sampled from the population of
  lots.
}
\source{
  Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
    and S-PLUS}, Springer, New York.  (Appendix A.20)

  Littell, R. C., Milliken, G. A., Stroup, W. W. and Wolfinger,
  R. D. (1996), \emph{SAS System for Mixed Models}, SAS Institute,
  Cary, NC.
}
\examples{
data(Oxide)
}
\keyword{datasets}

\eof
\name{PBG}
\alias{PBG}
\non_function{}
\title{Effect of Phenylbiguanide on Blood Pressure}
\description{
    The \code{PBG} data frame has 60 rows and 5 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{deltaBP}{
	    a numeric vector
	}
	\item{dose}{
	    a numeric vector
	}
	\item{Run}{
	    an ordered factor with levels
	    \code{T5} < \code{T4} < \code{T3} < \code{T2} < \code{T1} < \code{P5} < \code{P3} < \code{P2} < \code{P4} < \code{P1}
	}
	\item{Treatment}{
	    a factor with levels
	    \code{MDL 72222} 
	    \code{Placebo} 
	}
	\item{Rabbit}{
	    an ordered factor with levels
	    \code{5} < \code{3} < \code{2} < \code{4} < \code{1}
	}
    }
}
\details{
Data on an experiment to examine the effect of a antagonist MDL 72222
on the change in blood pressure experienced with increasing dosage of
phenylbiguanide are described in Ludbrook (1994) and analyzed
in Venables and Ripley (1999, section 8.8).  Each of five rabbits was exposed to
increasing doses of phenylbiguanide after having either a placebo or
the HD5-antagonist MDL 72222 administered.
}
\source{
    Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
      and S-PLUS}, Springer, New York.  (Appendix A.21)

    Venables, W. N. and Ripley, B. D. (1999) \emph{Modern Applied
      Statistics with S-PLUS (3rd ed)}, Springer, New York.

    Ludbrook, J. (1994), Repeated measurements and multiple comparisons
    in cardiovascular research, \emph{Cardiovascular Research},
    \bold{28}, 303-311.
}
\examples{
data(PBG)
}
\keyword{datasets}

\eof
\name{Phenobarb}
\alias{Phenobarb}
\non_function{}
\title{Phenobarbitol Kinetics}
\description{
  The \code{Phenobarb} data frame has 744 rows and 7 columns.
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{Subject}{
      an ordered factor identifying the infant.
    }
    \item{Wt}{
      a numeric vector giving the birth weight of the infant (kg).
    }
    \item{Apgar}{
      an ordered factor giving the the 5-minute Apgar score for
      the infant.  This is an indication of health of the newborn
      infant.
    }
    \item{ApgarInd}{
      a factor indicating whether the 5-minute Apgar score is \code{< 5}
      or \code{>= 5}. 
    }
    \item{time}{
      a numeric vector giving the time when the sample is drawn or
      drug administered (hr).
    }
    \item{dose}{
      a numeric vector giving the dose of drug administered
      (\eqn{u}{\mu}g/kg).
    }
    \item{conc}{
      a numeric vector giving the phenobarbital concentration in
      the serum (\eqn{u}{\mu}g/L).
    }
  }
}
\details{
  Data from a pharmacokinetics study of phenobarbital in neonatal
  infants.  During the first few days of life the infants receive
  multiple doses of phenobarbital for prevention of seizures.  At
  irregular intervals blood samples are drawn and serum phenobarbital
  concentrations are determined.  The data
  were originally given in Grasela and Donn(1985) and are analyzed
  in Boeckmann, Sheiner and Beal (1994), in
  Davidian and Giltinan (1995), and in Littell et al. (1996).
}
\source{
  Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
    and S-PLUS}, Springer, New York.  (Appendix A.23)

  Davidian, M. and Giltinan, D. M. (1995), \emph{Nonlinear Models for
    Repeated Measurement Data},  Chapman and Hall, London.  (section 6.6)

  Grasela and Donn (1985), Neonatal population pharmacokinetics of
  phenobarbital derived from routine clinical data,
  \emph{Developmental Pharmacology and Therapeutics}, \bold{8},
  374-383.

  Boeckmann, A. J., Sheiner, L. B., and Beal, S. L. (1994),
  \emph{NONMEM Users Guide: Part V}, University of California, San
  Francisco.

  Littell, R. C., Milliken, G. A., Stroup, W. W. and Wolfinger,
  R. D. (1996), \emph{SAS System for Mixed Models}, SAS Institute,
  Cary, NC.
}
\examples{
data(Phenobarb)
}
\keyword{datasets}

\eof
\name{Pixel}
\alias{Pixel}
\non_function{}
\title{X-ray pixel intensities over time}
\description{
    The \code{Pixel} data frame has 102 rows and 4 columns of data on the
    pixel intensities of CT scans of dogs over time
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{Dog}{
	    a factor with levels \code{1} to \code{10} designating the dog
	    on which the scan was made
	}
	\item{Side}{
	    a factor with levels \code{L} and \code{R} designating the side
	    of the dog being scanned
	}
	\item{day}{
	    a numeric vector giving the day post injection of the contrast
	    on which the scan was made
	}
	\item{pixel}{
	    a numeric vector of pixel intensities
	}
    }
}
\source{
    Pinheiro, J. C. and Bates, D. M. (2000) \emph{Mixed-effects Models in
	S and S-PLUS}, Springer.
}
\examples{
data(Pixel)
\dontrun{
Pixel$DS = getGroups(Pixel, ~ 1 | Dog/Side, level = 2)
fm1 <- lme(pixel ~ day + I(day^2), data = Pixel,
           random = list(DS = ~ 1, Dog = ~ 1))
summary(fm1)
VarCorr(fm1)
}
}
\keyword{datasets}

\eof
\name{Quinidine}
\alias{Quinidine}
\non_function{}
\title{Quinidine Kinetics}
\description{
  The \code{Quinidine} data frame has 1471 rows and 14 columns.
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{Subject}{
      a factor identifying the patient on whom the data were collected.
    }
    \item{time}{
      a numeric vector giving the time (hr) at which the drug was
      administered or the blood sample drawn.  This is measured
      from the time the patient entered the study.
    }
    \item{conc}{
      a numeric vector giving the serum quinidine concentration (mg/L).
    }
    \item{dose}{
      a numeric vector giving the dose of drug administered (mg).
      Although there were two different forms of quinidine
      administered, the doses were adjusted for differences in
      salt content by conversion to milligrams of quinidine base.
    }
    \item{interval}{
      a numeric vector giving the when the drug has been given at
      regular intervals for a sufficiently long period of time to
      assume steady state behavior, the interval is recorded.
    }
    \item{Age}{
      a numeric vector giving the age of the subject on entry to
      the study (yr).
    }
    \item{Height}{
      a numeric vector giving the height of the subject on entry
      to the study (in.).
    }
    \item{Weight}{
      a numeric vector giving the body weight of the subject (kg).
    }
    \item{Race}{
      a factor with levels
      \code{Caucasian}, 
      \code{Latin}, and
      \code{Black} identifying the race of the subject.
    }
    \item{Smoke}{
      a factor with levels
      \code{no} and
      \code{yes} giving smoking status at the time of the
      measurement.
    }
    \item{Ethanol}{
      a factor with levels
      \code{none}, 
      \code{current},
      \code{former} giving ethanol (alcohol) abuse status at the
      time of the measurement.
    }
    \item{Heart}{
      a factor with levels
      \code{No/Mild}, 
      \code{Moderate}, and 
      \code{Severe} indicating congestive heart failure for the subject.
    }
    \item{Creatinine}{
      an ordered factor with levels
      \code{< 50} < \code{>= 50} indicating the creatine clearance (mg/min).
    }
    \item{glyco}{
      a numeric vector giving the alpha-1 acid glycoprotein
      concentration (mg/dL).  Often measured at the same time as
      the quinidine concentration.
    }
  }
}
\details{
  Verme et al. (1992) analyze routine clinical data on
  patients receiving the drug quinidine as a treatment for cardiac
  arrythmia (atrial fibrillation of ventricular arrythmias).  All
  patients were receiving oral quinidine doses.  At irregular intervals
  blood samples were drawn and serum concentrations of quinidine were
  determined.  These data are
  analyzed in several publications, including Davidian and Giltinan (1995,
  section 9.3).
}
\source{
  Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
    and S-PLUS}, Springer, New York.  (Appendix A.25)

  Davidian, M. and Giltinan, D. M. (1995), \emph{Nonlinear Models for
    Repeated Measurement Data},  Chapman and Hall, London.

  Verme, C. N., Ludden,  T. M., Clementi, W. A. and Harris,
  S. C. (1992), Pharmacokinetics of quinidine in male patients: A
  population analysis, \emph{Clinical Pharmacokinetics}, \bold{22},
  468-480.
}
\examples{
data(Quinidine)
}
\keyword{datasets}

\eof
\name{Rail}
\alias{Rail}
\non_function{}
\title{Evaluation of Stress in Railway Rails}
\description{
    The \code{Rail} data frame has 18 rows and 2 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{Rail}{
	    an ordered factor identifying the rail on which the
	    measurement was made.
	}
	\item{travel}{
	  a numeric vector giving the travel time for ultrasonic
	  head-waves in the rail (nanoseconds).  The value given is the
	  original travel time minus 36,100 nanoseconds.
	}
    }
}
\details{
  Devore (2000, Example 10.10, p. 427) cites data from an article in
  \emph{Materials Evaluation} on ``a study of travel time for a certain
  type of wave that results from longitudinal stress of rails used for
  railroad track.''
}
\source{
    Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
	and S-PLUS}, Springer, New York.  (Appendix A.26)

    Devore, J. L. (2000), \emph{Probability and Statistics for
      Engineering and the Sciences (5th ed)}, Duxbury, Boston, MA.
}
\examples{
data(Rail)
}
\keyword{datasets}

\eof
\name{RatPupWeight}
\alias{RatPupWeight}
\non_function{}
\title{The weight of rat pups}
\description{
    The \code{RatPupWeight} data frame has 322 rows and 5 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{weight}{
	    a numeric vector
	}
	\item{sex}{
	    a factor with levels
	    \code{Male} 
	    \code{Female} 
	}
	\item{Litter}{
	    an ordered factor with levels
	    \code{9} < \code{8} < \code{7} < \code{4} < \code{2} < \code{10} < \code{1} < \code{3} < \code{5} < \code{6} < \code{21} < \code{22} < \code{24} < \code{27} < \code{26} < \code{25} < \code{23} < \code{17} < \code{11} < \code{14} < \code{13} < \code{15} < \code{16} < \code{20} < \code{19} < \code{18} < \code{12}
	}
	\item{Lsize}{
	    a numeric vector
	}
	\item{Treatment}{
	    an ordered factor with levels
	    \code{Control} < \code{Low} < \code{High}
	}
    }
}
\details{
}
\source{
    Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
	and S-PLUS}, Springer, New York.
}
\examples{
data(RatPupWeight)
}
\keyword{datasets}

\eof
\name{Relaxin}
\alias{Relaxin}
\non_function{}
\title{Assay for Relaxin}
\description{
    The \code{Relaxin} data frame has 198 rows and 3 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{Run}{
	    an ordered factor with levels
	    \code{5} < \code{8} < \code{9} < \code{3} < \code{4} < \code{2} < \code{7} < \code{1} < \code{6}
	}
	\item{conc}{
	    a numeric vector
	}
	\item{cAMP}{
	    a numeric vector
	}
    }
}
\details{
}
\source{
    Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
	and S-PLUS}, Springer, New York.
}
\examples{
data(Relaxin)
}
\keyword{datasets}

\eof
\name{Remifentanil}
\alias{Remifentanil}
\non_function{}
\title{Pharmacokinetics of remifentanil}
\description{
    The \code{Remifentanil} data frame has 2107 rows and 12 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{ID}{
	    a numeric vector
	}
	\item{Subject}{
	    an ordered factor
	}
	\item{Time}{
	    a numeric vector
	}
	\item{conc}{
	    a numeric vector
	}
	\item{Rate}{
	    a numeric vector
	}
	\item{Amt}{
	    a numeric vector
	}
	\item{Age}{
	    a numeric vector
	}
	\item{Sex}{
	    a factor with levels
	    \code{Female} 
	    \code{Male} 
	}
	\item{Ht}{
	    a numeric vector
	}
	\item{Wt}{
	    a numeric vector
	}
	\item{BSA}{
	    a numeric vector
	}
	\item{LBM}{
	    a numeric vector
	}
    }
}
\details{
}
\source{
    Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
	and S-PLUS}, Springer, New York.
}
\examples{
data(Remifentanil)
}
\keyword{datasets}

\eof
\name{Socatt}
\alias{Socatt}
\docType{data}
\title{Social Attitudes Survey}
\description{
  These data come from the British Social Attitudes (BSA) Survey started
  in 1983. The eligible persons were all adults aged 18 or over living
  in private households in Britain.  The data consist of completed
  results of 264 respondents out of 410.  
}
\usage{data(Socatt)}
\format{
  A data frame with 1056 observations on the following 9 variables.
  \describe{
    \item{district}{District ID - a factor}
    \item{respond}{Respondent code (within district) - a factor}
    \item{year}{A factor with levels \code{1983}, \code{1984},
      \code{1985}, and \code{1986}}
    \item{numpos}{An ordered factor giving the number of positive answers to
      seven questions.}
    \item{party}{Political party chosen - a factor.  Levels are
      \code{conservative}, \code{labour}, \code{Lib/SDP/Alliance},
      \code{others}, and \code{none}.}
    \item{class}{Self assessed social class - a factor.  Levels are
      \code{middle}, \code{upper working}, and \code{lower working}.}
    \item{gender}{Respondent's sex. (1=male, 2=female)}
    \item{age}{Age in years}
    \item{religion}{Religion - a factor.  Levels are \code{Roman
	Catholic}, \code{Protestant/Church of England}, \code{others},
       and \code{none}.}
  }
}
\details{
  These data are provided at \url{http://multilevel.ioe.ac.uk/softrev/}
  as an example of multilevel data with a multinomial response.  Results
  from several multilevel software packages are provided at this site.
}
\source{
  \url{http://multilevel.ioe.ac.uk/softrev/socatt.htm}
}
\references{
  McGrath, K. and Waterton, J. (1986). \emph{British Social Attitudes
    1983-1986 panel survey.} London, Social and Community Planning
  Research.
}
\examples{
data(Socatt)
str(Socatt)
summary(Socatt)
}
\keyword{datasets}

\eof
\name{Soybean}
\alias{Soybean}
\non_function{}
\title{Growth of soybean plants}
\description{
  The \code{Soybean} data frame has 412 rows and 5 columns.
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{Plot}{
      a factor giving a unique identifier for each plot.
    }
    \item{Variety}{
      a factor indicating the variety; Forrest (F) or Plant
      Introduction \#416937 (P).
    }
    \item{Year}{
      a factor indicating the year the plot was planted.
    }
    \item{Time}{
      a numeric vector giving the time the sample was taken (days
      after planting).
    }
    \item{weight}{
      a numeric vector giving the average leaf weight per plant (g).
    }
  }
}
\details{
  These data are described in
  Davidian and Giltinan (1995, 1.1.3, p.7) as ``Data from an
  experiment to compare growth patterns of two genotypes of soybeans:
  Plant Introduction \#416937 (P), an experimental strain, and Forrest
  (F), a commercial variety.''
}
\source{
  Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
    and S-PLUS}, Springer, New York.  (Appendix A.27)

  Davidian, M. and Giltinan, D. M. (1995), \emph{Nonlinear Models for
    Repeated Measurement Data},  Chapman and Hall, London.
}
\examples{
data(Soybean)
#summary(fm1 <- nlsList(SSlogis, data = Soybean))
}
\keyword{datasets}

\eof
\name{Spruce}
\alias{Spruce}
\non_function{}
\title{Growth of Spruce Trees}
\description{
  The \code{Spruce} data frame has 1027 rows and 4 columns.
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{Tree}{
      a factor giving a unique identifier for each tree.
    }
    \item{days}{
      a numeric vector giving the number of days since the
      beginning of the experiment.
    }
    \item{logSize}{
      a numeric vector giving the logarithm of an estimate of the
      volume of the tree trunk.
    }
    \item{plot}{
      a factor identifying the plot in which the tree was grown.
    }
  }
}
\details{
  Diggle, Liang, and Zeger (1994, Example 1.3, page 5)
  describe data on the growth of spruce trees that have been exposed to
  an ozone-rich atmosphere or to a normal atmosphere.
}
\source{
  Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
    and S-PLUS}, Springer, New York.  (Appendix A.28)

  Diggle, Peter J., Liang, Kung-Yee and Zeger, Scott L. (1994),
  \emph{Analysis of longitudinal data}, Oxford University Press,
  Oxford.
}
\examples{
data(Spruce)
}
\keyword{datasets}

\eof
\name{Tetracycline1}
\alias{Tetracycline1}
\non_function{}
\title{Pharmacokinetics of tetracycline}
\description{
    The \code{Tetracycline1} data frame has 40 rows and 4 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{conc}{
	    a numeric vector
	}
	\item{Time}{
	    a numeric vector
	}
	\item{Subject}{
	    an ordered factor with levels
	    \code{5} < \code{3} < \code{2} < \code{4} < \code{1}
	}
	\item{Formulation}{
	    a factor with levels
	    \code{tetrachel} 
	    \code{tetracyn} 
	}
    }
}
\details{
}
\source{
    Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
	and S-PLUS}, Springer, New York.
}
\examples{
data(Tetracycline1)
}
\keyword{datasets}

\eof
\name{Tetracycline2}
\alias{Tetracycline2}
\non_function{}
\title{Pharmacokinetics of tetracycline}
\description{
    The \code{Tetracycline2} data frame has 40 rows and 4 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{conc}{
	    a numeric vector
	}
	\item{Time}{
	    a numeric vector
	}
	\item{Subject}{
	    an ordered factor with levels
	    \code{4} < \code{5} < \code{2} < \code{1} < \code{3}
	}
	\item{Formulation}{
	    a factor with levels
	    \code{Berkmycin} 
	    \code{tetramycin} 
	}
    }
}
\details{
}
\source{
    Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
	and S-PLUS}, Springer, New York.
}
\examples{
data(Tetracycline2)
}
\keyword{datasets}

\eof
\name{VarCorr-class}
\docType{class}
\alias{VarCorr-class}
\alias{show,VarCorr-method}
\title{Class "VarCorr"}
\description{The variance and correlation information for a
  random-effects model.}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("VarCorr", ...)}.
}
\section{Slots}{
  \describe{
    \item{\code{scale}:}{The estimated standard deviation of the lowest
      level noise term in the model.}
    \item{\code{reSumry}:}{Object of class \code{"list"}, a list
      containing the summary of the positive-definte matrices for the
      random-effects levels.}
    \item{\code{useScale}:}{Object of class \code{"logical"}, if TRUE
      the slot \code{scale} is the estimated within-groups standard deviation.}
  }
}
\section{Methods}{
  \describe{
    \item{\link[methods:show]{show}}{\code{signature(object =
	"VarCorr")}: show the object.}
  }
}
\keyword{classes}

\eof
\name{VarCorr}
\docType{genericFunction}
\alias{VarCorr}
\title{Extract variance and correlation components}
% \arguments{
%  \item{x}{a fitted model object, usually an object inheriting from
%      class \code{lme}. 
%  }
% }
\description{
  Extract the estimated variances, standard
  deviations, and correlations of the random-effects terms in a
  linear mixed-effects model, of class \code{lme}, or a generalized
  linear mixed-effects model. When appropriate,
  the within-group error variance and standard deviation are also
  calculated.
}
\value{
  an object of class \code{VarCorr}.
}
%\author{Saikat DebRoy \email{saikat@stat.wisc.edu} and Douglas Bates \email{bates@stat.wisc.edu}}
\seealso{\code{\link{lme}}, \code{\link{GLMM}}, \code{\link{VarCorr-class}}}
\examples{
data(bdf)
fm <- lme(langPOST ~ IQ.ver.cen + avg.IQ.ver.cen, data = bdf,
          random = ~ IQ.ver.cen | schoolNR)
VarCorr(fm)
}
\keyword{models}

\eof
\name{Wafer}
\alias{Wafer}
\non_function{}
\title{Modeling of Analog MOS Circuits}
\description{
    The \code{Wafer} data frame has 400 rows and 4 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{Wafer}{
	    a factor with levels
	    \code{1} 
	    \code{2} 
	    \code{3} 
	    \code{4} 
	    \code{5} 
	    \code{6} 
	    \code{7} 
	    \code{8} 
	    \code{9} 
	    \code{10} 
	}
	\item{Site}{
	    a factor with levels
	    \code{1} 
	    \code{2} 
	    \code{3} 
	    \code{4} 
	    \code{5} 
	    \code{6} 
	    \code{7} 
	    \code{8} 
	}
	\item{voltage}{
	    a numeric vector
	}
	\item{current}{
	    a numeric vector
	}
    }
}
\details{
}
\source{
    Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
	and S-PLUS}, Springer, New York.
}
\examples{
data(Wafer)
}
\keyword{datasets}

\eof
\name{Wheat}
\alias{Wheat}
\non_function{}
\title{Yields by growing conditions}
\description{
    The \code{Wheat} data frame has 48 rows and 4 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{Tray}{
	    an ordered factor with levels
	    \code{3} < \code{1} < \code{2} < \code{4} < \code{5} < \code{6} < \code{8} < \code{9} < \code{7} < \code{12} < \code{11} < \code{10}
	}
	\item{Moisture}{
	    a numeric vector
	}
	\item{fertilizer}{
	    a numeric vector
	}
	\item{DryMatter}{
	    a numeric vector
	}
    }
}
\details{
}
\source{
    Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
	and S-PLUS}, Springer, New York.
}
\examples{
data(Wheat)
}
\keyword{datasets}

\eof
\name{Wheat2}
\alias{Wheat2}
\non_function{}
\title{Wheat Yield Trials}
\description{
    The \code{Wheat2} data frame has 224 rows and 5 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{Block}{
	    an ordered factor with levels
	    \code{4} < \code{2} < \code{3} < \code{1}
	}
	\item{variety}{
	    a factor with levels
	    \code{ARAPAHOE} 
	    \code{BRULE} 
	    \code{BUCKSKIN} 
	    \code{CENTURA} 
	    \code{CENTURK78} 
	    \code{CHEYENNE} 
	    \code{CODY} 
	    \code{COLT} 
	    \code{GAGE} 
	    \code{HOMESTEAD} 
	    \code{KS831374} 
	    \code{LANCER} 
	    \code{LANCOTA} 
	    \code{NE83404} 
	    \code{NE83406} 
	    \code{NE83407} 
	    \code{NE83432} 
	    \code{NE83498} 
	    \code{NE83T12} 
	    \code{NE84557} 
	    \code{NE85556} 
	    \code{NE85623} 
	    \code{NE86482} 
	    \code{NE86501} 
	    \code{NE86503} 
	    \code{NE86507} 
	    \code{NE86509} 
	    \code{NE86527} 
	    \code{NE86582} 
	    \code{NE86606} 
	    \code{NE86607} 
	    \code{NE86T666} 
	    \code{NE87403} 
	    \code{NE87408} 
	    \code{NE87409} 
	    \code{NE87446} 
	    \code{NE87451} 
	    \code{NE87457} 
	    \code{NE87463} 
	    \code{NE87499} 
	    \code{NE87512} 
	    \code{NE87513} 
	    \code{NE87522} 
	    \code{NE87612} 
	    \code{NE87613} 
	    \code{NE87615} 
	    \code{NE87619} 
	    \code{NE87627} 
	    \code{NORKAN} 
	    \code{REDLAND} 
	    \code{ROUGHRIDER} 
	    \code{SCOUT66} 
	    \code{SIOUXLAND} 
	    \code{TAM107} 
	    \code{TAM200} 
	    \code{VONA} 
	}
	\item{yield}{
	    a numeric vector
	}
	\item{latitude}{
	    a numeric vector
	}
	\item{longitude}{
	    a numeric vector
	}
    }
}
\details{
}
\source{
    Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
	and S-PLUS}, Springer, New York.
}
\examples{
data(Wheat2)
}
\keyword{datasets}

\eof
\name{bdf}
\alias{bdf}
\non_function{}
\title{Language scores}
\usage{data(bdf)}
\description{
The \code{bdf} data frame has 2287 rows and 25 columns of language
scores from grade 8 pupils in elementary schools in The Netherlands.
}
\format{
  \describe{
    \item{schoolNR}{a factor denoting the school.}
    \item{pupilNR}{a factor denoting the pupil.}
    \item{IQ.verb}{a numeric vector of verbal IQ scores}
    \item{IQ.perf}{a numeric vector of IQ scores.}
    \item{sex}{Sex of the student.}
    \item{Minority}{a factor indicating if the student is a member of a
      minority group.}
    \item{repeatgr}{an ordered factor indicating if one or more grades
      have been repeated.}
    \item{aritPRET}{a numeric vector}
    \item{classNR}{a numeric vector}
    \item{aritPOST}{a numeric vector}
    \item{langPRET}{a numeric vector}
    \item{langPOST}{a numeric vector}
    \item{ses}{a numeric vector of socioeconomic status indicators.}
    \item{denomina}{a factor indicating of the school is a public
      school, a Protestant private school, a Catholic private school, or
      a non-denominational private school.}
    \item{schoolSES}{a numeric vector}
    \item{satiprin}{a numeric vector}
    \item{natitest}{a factor with levels \code{0} and \code{1}}
    \item{meetings}{a numeric vector}
    \item{currmeet}{a numeric vector}
    \item{mixedgra}{a factor indicating if the class is a mixed-grade class.}
    \item{percmino}{a numeric vector}
    \item{aritdiff}{a numeric vector}
    \item{homework}{a numeric vector}
    \item{classsiz}{a numeric vector}
    \item{groupsiz}{a numeric vector}
  }
}
\source{
  \url{http://stat.gamma.rug.nl/snijders/multilevel.htm}
}
\references{
  Snijders, Tom and Bosker, Roel (1999), \emph{Multilevel Analysis: An
    Introduction to Basic and Advanced Multilevel Modeling}, Sage.
}
\examples{
data(bdf)
summary(bdf)
}
\keyword{datasets}

\eof
\name{egsingle}
\alias{egsingle}
\docType{data}
\title{US Sustaining Effects study}
\description{
  A subset of the mathematics scores from the U.S. Sustaining Effects
  Study.  The subset consists of information on 1721 students from 60 schools
}
\usage{data(egsingle)}
\format{
  A data frame with 7230 observations on the following 12 variables.
  \describe{
    \item{schoolid}{a factor of school identifiers}
    \item{childid}{a factor of student identifiers}
    \item{year}{a numeric vector indicating the year of the test}
    \item{grade}{a numeric vector indicating the student's grade}
    \item{math}{a numeric vector of test scores on the IRT scale score metric}
    \item{retained}{a factor with levels \code{0} \code{1} indicating if
    the student has been retained in a grade.}
    \item{female}{a factor with levels \code{Female} \code{Male}
      indicating the student's sex}
    \item{black}{a factor with levels \code{0} \code{1} indicating if
      the student is Black}
    \item{hispanic}{a factor with levels \code{0} \code{1} indicating if
    the student is Hispanic}
    \item{size}{a numeric vector indicating the number of students
      enrolled in the school}
    \item{lowinc}{a numeric vector giving the percentage of low-income
      students in the school}
    \item{mobility}{a numeric vector}
  }
}
%\details{}
\source{
  These data are distributed with the HLM software package (Bryk,
  Raudenbush and Congdon, 1996).  Conversion to the R format is
  described in Doran and Lockwood (2004).
}
\references{
  Doran, Harold C. and Lockwood, J.R. (2004), \emph{Fitting value-added
    models in R}, (submitted).
}
\examples{
data(egsingle)
str(egsingle)
fm1 <- lme(math~year*size+female, egsingle,
           random = ~1|schoolid/childid,
           control = list(EMv = TRUE, msV = TRUE, opt = 'optim'))
summary(fm1)
}
\keyword{datasets}

\eof
\name{ergoStool}
\alias{ergoStool}
\non_function{}
\title{Ergometrics experiment with stool types}
\description{
    The \code{ergoStool} data frame has 36 rows and 3 columns.
}
\format{
    This data frame contains the following columns:
    \describe{
	\item{effort}{
	    a numeric vector giving the effort (Borg scale) required to
	    arise from a stool.
	}
	\item{Type}{
	    a factor with levels
	    \code{T1}, 
	    \code{T2}, 
	    \code{T3}, and 
	    \code{T4} giving the stool type.
	}
	\item{Subject}{
	    an ordered factor giving a unique identifier for the subject
	    in the experiment.
	}
    }
}
\details{
  Devore (2000) cites data from an article in \emph{Ergometrics} (1993,
  pp. 519-535) on ``The Effects of a Pneumatic Stool and a One-Legged
  Stool on Lower Limb Joint Load and Muscular Activity.''
}
\source{
    Pinheiro, J. C. and Bates, D. M. (2000), \emph{Mixed-Effects Models in S
	and S-PLUS}, Springer, New York.  (Appendix A.9)

    Devore, J. L. (2000), \emph{Probability and Statistics for
      Engineering and the Sciences (5th ed)}, Duxbury, Boston, MA.
}
\examples{
data(ergoStool)
fm1 <-
   lme(effort ~ Type, data = ergoStool, random = ~ 1 | Subject)
anova( fm1 )
}
\keyword{datasets}

\eof
\name{fixed.effects}
\docType{genericFunction}
\alias{fixed.effects}
\alias{fixef}
\alias{fixef,ANY-method}
\alias{fixef,ssclme-method}
\alias{fixef,lme-method}
\title{Extract Fixed Effects}
\description{
  Extract the estimates of the fixed effects parameters from a fitted model.
}
\usage{
fixef(object, \dots)
fixed.effects(object, \dots)  # deprecated
}
\arguments{
 \item{object}{any fitted model object from which fixed effects
   estimates can be extracted.}
 \item{\dots}{optional additional arguments. Currently none are used in
   any methods.}
}
\value{
  a named numeric vector of fixed effects estimates.
}
%\seealso{}
%\examples{}
\keyword{models}

\eof
\name{formulas}
\title{Utilities for formulas}
\alias{getCovariate}
\alias{getCovariateFormula}
\alias{getGroups}
\alias{getGroups,data.frame,formula-method}
\alias{getGroups,groupedData-method}
\alias{getGroups,groupedData,missing-method}
\alias{getGroupsFormula}
\alias{getGroupsFormula,ANY-method}
\alias{getResponse}
\alias{getResponseFormula}
\alias{subFormula}
\alias{splitFormula}
\description{
  These generic functions extract sub-formulas or values of components
  from a formula/data pair.
}
\usage{
getCovariate(object, form, data)
getCovariateFormula(object)
getGroups(object, form, level, data, sep, \dots)
getGroupsFormula(object, asList, sep)
getResponse(object, form)
getResponseFormula(object)
subFormula(form, pos)
splitFormula(form, sep)
}
\arguments{
  \item{object}{a formula or an object that can provide a formula}
  \item{form}{an optional formula with a conditioning expression on its
    right hand side (i.e. an expression involving the \code{|}
    operator). Defaults to \code{formula(object)}.}
  \item{level}{a positive integer vector with the level(s) of grouping to
    be used when multiple nested levels of grouping are present. This
    argument is optional for most methods of this generic function and
    defaults to all levels of nesting.}
  \item{data}{a data frame in which to interpret the variables named in
    \code{form}. Optional for most methods.}
  \item{asList}{an optional logical value. If \code{TRUE} the returned
    value with be a list of formulas; else, if \code{FALSE} the returned
    value will be a one-sided formula. Defaults to \code{FALSE}.}
  \item{sep}{character, the separator to use between group levels when
    multiple levels are collapsed.  Defaults to \code{'/'}.}
  \item{pos}{the integer index of the component of the formula to
    return.  Defaults to \code{2}.}
  \item{\dots}{Optional arguments that are passed to some methods.  None
    used at present.}
}
\value{
  \code{getGroupsFormula} returns a one-sided formula, or a list of
  one-sided formulas, giving the grouping structure associated with
  \code{formula(object)}. If no conditioning expression is present in
  \code{formula(object)} a \code{NULL} value is returned.
}
%\seealso{}
\examples{
form = resp ~ cov1 + cov2 | grp1/grp2
getResponseFormula(form)
getCovariateFormula(form)
getGroupsFormula(form)
getGroupsFormula(form, asList = TRUE)
}
\keyword{models}

\eof
\name{groupedData-class}
\docType{class}
\alias{groupedData-class}
\alias{$,groupedData-method}
\alias{$<-,groupedData-method}
\alias{[,groupedData,missing,ANY,logical-method}
\alias{[,groupedData,missing,ANY,missing-method}
\alias{[,groupedData,ANY,missing,logical-method}
\alias{[,groupedData,ANY,missing,missing-method}
\alias{[,groupedData,ANY,ANY,missing-method}
\alias{[,groupedData,ANY,ANY,logical-method}
\alias{[<-,groupedData,ANY,ANY-method}
\alias{[<-,groupedData,ANY,missing-method}
\alias{[<-,groupedData,missing-method}
\alias{[[,groupedData,ANY,missing-method}
\alias{[[,groupedData,ANY,ANY-method}
\alias{coerce,groupedData,data.frame-method}
\alias{formula,groupedData-method}
\alias{lmList,formula,groupedData-method}
\alias{lmList,missing,groupedData-method}
\alias{plot,groupedData,missing-method}
\alias{show,groupedData-method}
\alias{summary,groupedData-method}

\title{Class "groupedData"}
\description{A \code{groupedData} object is at least a data.frame and a
  display  formula that provides a grouping structure.  At present we
  are using an old-style class for this.}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{new("groupedData",
    ...)} or by calls to the \code{groupedData} constructor function.
}
\section{Slots}{
  \describe{
    \item{\code{data}:}{The actual data; an object of class \code{"data.frame"} }
    \item{\code{formula}:}{The display formula; an object of class
      \code{"formula"}} 
    \item{\code{outer}:}{A formula all of whose variables are outer to the
      grouping factor}
    \item{\code{inner}:}{A formula of factors all of whose variables are
      inner to the grouping factor.}
    \item{\code{labels}:}{An optional list of default labels for the
      \code{x} and \code{y} axes of the default plot.}
    \item{\code{units}:}{An optional list of default units
      specifications for the \code{x} and \code{y} axes of the default
      plot.} 
  }
}
\section{Methods}{
  \describe{
    \item{\$}{\code{signature(x = "groupedData")}: ... }
    \item{\$<-}{\code{signature(x = "groupedData")}: ... }
    \item{[}{\code{signature(x = "groupedData", i = "missing", j = "ANY", drop = "logical")}: ... }
    \item{[}{\code{signature(x = "groupedData", i = "missing", j = "ANY", drop = "missing")}: ... }
    \item{[}{\code{signature(x = "groupedData", i = "ANY", j = "missing", drop = "logical")}: ... }
    \item{[}{\code{signature(x = "groupedData", i = "ANY", j = "missing", drop = "missing")}: ... }
    \item{[}{\code{signature(x = "groupedData", i = "ANY", j = "ANY", drop = "missing")}: ... }
    \item{[}{\code{signature(x = "groupedData", i = "ANY", j = "ANY", drop = "logical")}: ... }
    \item{[<-}{\code{signature(x = "groupedData", i = "ANY", j = "ANY")}: ... }
    \item{[<-}{\code{signature(x = "groupedData", i = "ANY", j = "missing")}: ... }
    \item{[<-}{\code{signature(x = "groupedData", i = "missing")}: ... }
    \item{[[}{\code{signature(x = "groupedData", i = "ANY", j = "missing")}: ... }
    \item{[[}{\code{signature(x = "groupedData", i = "ANY", j = "ANY")}: ... }
    \item{coerce}{\code{signature(from = "groupedData", to = "data.frame")}: ... }
    \item{formula}{\code{signature(x = "groupedData")}: ... }
    \item{lmList}{\code{signature(formula = "formula", data = "groupedData")}: ... }
    \item{lmList}{\code{signature(formula = "missing", data = "groupedData")}: ... }
    \item{plot}{\code{signature(x = "groupedData", y = "missing")}: ... }
    \item{show}{\code{signature(object = "groupedData")}: ... }
    \item{summary}{\code{signature(object = "groupedData")}: ... }
  }
}
%\references{}
%\author{}
%\note{}
\seealso{\code{\link{groupedData}}}
%\examples{}
\keyword{classes}

\eof
\name{groupedData}
\alias{groupedData}
\alias{convertFromS3groupedData}
\title{Creation of groupedData objects}
\description{
  \code{groupedData} creates groupedData objects.
  \code{convertFromS3groupedData} converts older S3 style objects of the
  same class name used in the \code{nlme} package.
}
\usage{
groupedData(formula, data = sys.parent(1),
            order.groups = TRUE,
            FUN = function(x) max(x, na.rm = TRUE),
            outer = ~0, inner = ~0,
            labels = list(), units = list())
convertFromS3groupedData(from)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{formula}{ ~~Describe \code{formula} here~~ }
  \item{data}{ ~~Describe \code{data} here~~ }
  \item{order.groups}{ ~~Describe \code{order.groups} here~~ }
  \item{FUN}{ ~~Describe \code{FUN} here~~ }
  \item{outer}{ ~~Describe \code{outer} here~~ }
  \item{inner}{ ~~Describe \code{inner} here~~ }
  \item{labels}{ ~~Describe \code{labels} here~~ }
  \item{units}{ ~~Describe \code{units} here~~ }
  \item{from}{ an object of class "groupedData" as used in package
    \code{nlme}
  }
}
\details{
  See \code{nlme} docs for now. \code{order.groups, FUN} are currently
  ignored.
}
\value{
  An object of formal class \code{groupedData}
}
%\references{ ~put references to the literature/web site here ~ }
%\author{ ~~who you are~~ }
%\note{ ~~further notes~~ }

\seealso{\code{\link{groupedData-class}}}
\examples{
##---- Should be DIRECTLY executable !! ----
}
\keyword{manip}


\eof
\name{gsummary}
\alias{gsummary}
\docType{methods}
\alias{gsummary-methods}
\alias{gsummary,ANY,ANY,ANY,ANY,missing-method}
\alias{gsummary,groupedData,ANY,ANY,ANY,factor-method}
\alias{gsummary,data.frame,ANY,ANY,ANY,factor-method}
\title{Summarize a data frame by group}
\description{
  Provide a summary of the variables in a data frame by groups of rows.
  This is most useful with a \code{groupedData} object to examine the
  variables by group.
}
\usage{
gsummary(object, FUN, form, level, groups, omitGroupingFactor = FALSE, invariantsOnly = FALSE, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
   \item{object}{an object to be summarized - usually a \code{groupedData}
   object or a \code{data.frame}.
 }
 \item{FUN}{an optional summary function or a list of summary functions
   to be applied to each variable in the frame.  The function or
   functions are applied only to variables in \code{object} that vary
   within the groups defined by \code{groups}.  Invariant variables are
   always summarized by group using the unique value that they assume
   within that group.  If \code{FUN} is a single
   function it will be applied to each non-invariant variable by group
   to produce the summary for that variable.  If \code{FUN} is a list of
   functions, the names in the list should designate classes of
   variables in the frame such as \code{ordered}, \code{factor}, or
   \code{numeric}.  The indicated function will be applied to any
   non-invariant variables of that class.  The default functions to be
   used are \code{mean} for numeric factors, and \code{Mode} for both
   \code{factor} and \code{ordered}.  The \code{Mode} function, defined
   internally in \code{gsummary}, returns the modal or most popular
   value of the variable.  It is different from the \code{mode} function
   that returns the S-language mode of the variable.
 }
 \item{omitGroupingFactor}{an optional logical value.  When \code{TRUE}
   the grouping factor itself will be omitted from the group-wise
   summary but the levels of the grouping factor will continue to be
   used as the row names for the data frame that is produced by the
   summary. Defaults to \code{FALSE}.
 }
 \item{form}{an optional one-sided formula that defines the groups.
   When this formula is given, the right-hand side is evaluated in
   \code{object}, converted to a factor if necessary, and the unique
   levels are used to define the groups.  Defaults to
   \code{formula(object)}.
 } 
 \item{level}{an optional positive integer giving the level of grouping
   to be used in an object with multiple nested grouping levels.
   Defaults to the highest or innermost level of grouping.}
 \item{groups}{an optional factor that will be used to split the 
   rows into groups.  Defaults to \code{getGroups(object, form, level)}.
 }
 \item{invariantsOnly}{an optional logical value.  When \code{TRUE} only 
   those covariates that are invariant within each group will be
   summarized.  The summary value for the group is always the unique
   value taken on by that covariate within the group.  The columns in
   the summary are of the same class as the corresponding columns in
   \code{object}. By definition, the grouping factor itself must be an
   invariant.   When combined with \code{omitGroupingFactor = TRUE},
   this option can be used to discover is there are invariant covariates 
   in the data frame.  Defaults to \code{FALSE}.
 }
 \item{\dots}{optional additional arguments to the summary functions
   that are invoked on the variables by group.  Often it is helpful to
   specify \code{na.rm = TRUE}.
 }
}
\value{
  A \code{data.frame} with one row for each level of the grouping
  factor.  The number of columns is at most the number of columns in
  \code{object}.
}
%\references{ ~put references to the literature/web site here ~ }
%\author{ ~~who you are~~ }
%\note{ ~~further notes~~ }
\seealso{\code{\link{summary}}, \code{\link{groupedData}},
  \code{\link{getGroups}}} 
\examples{
data(Early)
class(Early)
gsummary(Early, groups = Early$id)
gsummary(Early, groups = Early$id, invariantsOnly = TRUE)
}
\keyword{manip}
\keyword{methods}

\eof
\name{guImmun}
\alias{guImmun}
\docType{data}
\title{Immunization in Guatemala}
\description{
  Immunizations received by children in Guatemala.
}
\usage{data(guImmun)}
\format{
  A data frame with 2159 observations on the following 13 variables.
  \describe{
    \item{kid}{a factor identifying the child}
    \item{mom}{a factor identifying the family.}
    \item{comm}{a factor identifying the community.}
    \item{immun}{a factor indicating if the child received a
      complete set of immunizations. All children in this data frame
      received at least one immunization.}
    \item{kid2p}{a factor indicating if the child was 2 years or older
      at the time of the survey.}
    \item{mom25p}{a factor indicating if the mother was 25 years or older.}
    \item{ord}{an factor indicating the child's birth's order within the
      family.  Levels are \code{01} - first child, \code{23} - second or
      third child, \code{46} - fourth to sixth child, \code{7p} -
      seventh or later child.}
    \item{ethn}{a factor indicating the mother's ethnicity.  Levels are
      \code{L} - Ladino, \code{N} - indigenous not speaking Spanish, and
      \code{S} - indigenous speaking Spanish.}
    \item{momEd}{a factor describing the mother's level of eduation.
      Levels are \code{N} - not finished primary, \code{P} - finished
      primary, \code{S} - finished secondary}
    \item{husEd}{a factor describing the husband's level of education.
      Levels are the same as for \code{momEd} plus \code{U} - unknown.}
    \item{momWork}{a factor indicating if the mother had ever
      worked outside the home.}
    \item{rural}{a factor indicating if the family's location is
      considered rural or urban.}
    \item{pcInd81}{the percentage of indigenous population in the
      community at the 1981 census.}
  }
}
%\details{}
\source{
  These data are available at
  \url{http://data.princeton.edu/multilevel/guImmun.dat}.  Multiple
  indicator columns in the original data table have been collapsed to
  factors for this data frame.
}
\references{
  Rodriguez, Germn and Goldman, Noreen (1995), "Improved estimation
  procedures for multilevel models with binary response: a case-study",
  \emph{Journal of the Royal Statistical Society, Series A}, \bold{164},
  339-355.
}
\examples{
data(guImmun)
summary(guImmun)
}
\keyword{datasets}

\eof
\name{guPrenat}
\alias{guPrenat}
\docType{data}
\title{Prenatal care in Guatemala}
\description{
  Data on the prenatal care received by mothers in Guatemala.
}
\usage{data(guPrenat)}
\format{
  A data frame with 2449 observations on the following 15 variables.
  \describe{
    \item{kid}{a factor identifying the birth}
    \item{mom}{a factor identifying the mother or family}
    \item{cluster}{a factor identifying the community}
    \item{prenat}{a factor indicating if traditional or modern prenatal
      care was provided for the birth.}
    \item{childAge}{an ordered factor of the child's age at the time of
      the survey. }
    \item{motherAge}{a factor indicating if the mother was older or
      younger.  The cut-off age is 25 years.}
    \item{birthOrd}{an ordered factor for the birth's order within the family.}
    \item{indig}{a factor indicating if the mother is Ladino, or
      indigenous not speaking Spanish, or indigenous speaking Spanish.}
    \item{momEd}{a factor describing the mother's level of eduation.}
    \item{husEd}{a factor describing the husband's level of education.}
    \item{husEmpl}{a factor describing the husband's employment status.}
    \item{toilet}{a factor indicating if there is a modern toilet in the
      house.}
    \item{TV}{a factor indicating if there is a TV in the house and, if
      so, the frequency with which it is used.}
    \item{pcInd81}{the percentage of indigenous population in the
      community at the 1981 census.}
    \item{ssDist}{distance from the community to the nearest clinic.}
  }
}
%\details{}
\source{
  These data are available at
  \url{http://data.princeton.edu/multilevel/guPrenat.dat}.  Multiple
  indicator columns in the original data table have been collapsed to
  factors for this data frame.
}
\references{
  Rodriguez, Germn and Goldman, Noreen (1995), "Improved estimation
  procedures for multilevel models with binary response: a case-study",
  \emph{Journal of the Royal Statistical Society, Series A}, \bold{164},
  339-355.
}
\examples{
data(guPrenat)
summary(guPrenat)
}
\keyword{datasets}

\eof
% $Id: intervals.Rd,v 1.1 2003/06/03 18:31:33 bates Exp $
\name{intervals}
\title{Confidence Intervals on Coefficients}
\usage{
intervals(object, level, \dots)
}
\alias{intervals}
\arguments{
 \item{object}{a fitted model object from which parameter estimates can
   be extracted.}
 \item{level}{an optional numeric value for the interval confidence
   level. Defaults to 0.95.}
 \item{\dots}{some methods for the generic may require additional
   arguments.}
}
\description{
  Confidence intervals on the parameters associated with the model
  represented by \code{object} are obtained. This function is generic;
  method functions can be written to handle specific classes of
  objects. Classes which already have methods for this function include:
  \code{gls}, \code{lme}, and \code{lmList}. 
}
\value{
  will depend on the method function used; see the appropriate documentation.
}
\seealso{\code{\link{confint}}}
} 
%\author{Jose Pinheiro \email{Jose.Pinheiro@pharma.novartis.com} and Douglas Bates \email{bates@stat.wisc.edu}}
%\examples{}
\keyword{models}

\eof
\name{lmList-class}
\docType{class}
\alias{lmList-class}
\alias{coef,lmList-method}
\alias{formula,lmList-method}
\alias{intervals,lmList-method}
\alias{plot,lmList-method}
\alias{pooledSD,lmList-method}
\alias{show,lmList-method}
\alias{update,lmList-method}
\title{Class "lmList"}
\description{A list of objects of class \code{lm} with a common model.}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{new("lmList", ...)}.
}
\section{Slots}{
  \describe{
    \item{\code{.Data}:}{Object of class \code{"list"}, a list of
      objects of class \code{lm}}
    \item{\code{call}:}{Object of class \code{"call"}, the function call
      used to create the \code{lmList} object.}
    \item{\code{pool}:}{Object of class \code{"logical"}, if TRUE then
      calculate the pooled standard deviation estimate when displaying
      the object.}
  }
}
\section{Extends}{
Class \code{"list"}, from data part.
Class \code{"vector"}, by class "list".
}
\section{Methods}{
  \describe{
    \item{coef}{\code{signature(object = "lmList")}: extract the
      coefficients for the linear models.}
    \item{formula}{\code{signature(x = "lmList")}: extract the formula
      used when creating the lmList object.}
    \item{intervals}{\code{signature(object = "lmList")}: confidence
      intervals for the fitted linear models.}
    \item{plot}{\code{signature(x = "lmList")}: plot the fitted linear
      models.}
    \item{pooledSD}{\code{signature(object = "lmList")}: the pooled
      standard deviation estimate from the fitted linear models.}
    \item{\link[methods:show]{show}}{\code{signature(object =
	"lmList")}: show the object.}
    \item{\link[base:update]{update}}{\code{signature(object =
	"lmList")}: update the fit.}
    
  }
}
\keyword{classes}

\eof
% $Id: lmList.Rd,v 1.4 2003/11/01 04:13:18 deepayan Exp $
\name{lmList}
\alias{lmList}
\alias{lmList,formula,data.frame-method}
\title{List of lm Objects with a Common Model}
\usage{
lmList(formula, data, level, subset, na.action, pool)
}
\arguments{
  \item{formula}{For \code{lmList},
    a linear formula object of the form \code{y ~ x1+...+xn | g}.
    In the formula object, \code{y}
    represents the response, \code{x1,...,xn} the covariates, and
    \code{g} the grouping factor specifying the partitioning of the data
    according to which different \code{lm} fits should be performed. The
    grouping factor \code{g} may be omitted from the formula, in which
    case the grouping structure will be obtained from \code{data}, which
    must inherit from class \code{groupedData}.
  }
  \item{data}{
    a data frame in which to interpret the variables named in
    \code{object}. 
  }
  \item{level}{
    an optional integer specifying the level of grouping to be used when 
    multiple nested levels of grouping are present.
  }
 \item{subset}{an optional expression indicating which subset of the rows of
   \code{data} should  be  used in the fit. This can be a logical
   vector, or a numeric vector indicating which observation numbers are
   to be included, or a  character  vector of the row names to be
   included.  All observations are included by default.}
 \item{na.action}{a function that indicates what should happen when the
   data contain \code{NA}s.  The default action (\code{na.fail}) causes
   \code{lmList} to print an error message and terminate if there are any
   incomplete observations.
 }
 \item{pool}{
   an optional logical value that is preserved as an attribute of the
   returned value.  This will be used as the default for \code{pool} in
   calculations of standard deviations or standard errors for summaries.
 }
}
\description{
  \code{Data} is partitioned according to the levels of the grouping
  factor \code{g} and individual \code{lm} fits are obtained for each
  \code{data} partition, using the model defined in \code{object}.
}

\value{
  an object of class lmList which is a list of \code{lm} objects with as
  many components as the number of groups defined by the grouping factor.
}

\seealso{
\code{\link[base:lm]{lm}}
}
\examples{
data(Orthodont)
fm1 <- lmList(distance ~ age | Subject, Orthodont)
fm1
}
\keyword{models}


\eof
\name{lme-class}
\docType{class}
\alias{lme-class}
\alias{VarCorr,lme-method}
\alias{VarCorr,ssclme-method}
\alias{anova,lme-method}
\alias{anova,ssclme-method}
\alias{coef,lme-method}
\alias{deviance,lme-method}
\alias{deviance,ssclme-method}
\alias{fitted,lme-method}
\alias{formula,lme-method}
\alias{logLik,lme-method}
\alias{plot,lme-method}
\alias{ranef,lme-method}
\alias{ranef,ssclme-method}
\alias{residuals,lme-method}
\alias{show,lme-method}
\alias{show,ssclme-method}
\alias{summary,lme-method}
\alias{summary,ssclme-method}
\alias{update,lme-method}
\alias{vcov,lme-method}
\alias{vcov,ssclme-method}
\title{Class "lme"}
\description{A fitted linear mixed-effects model.}
\section{Objects from the Class}{
  Objects are usually created by calls to the constructor function
  \code{lme}.  They also can be created by calls of the form
  \code{new("lme", ...)}.
}
\section{Slots}{
  \describe{
    \item{\code{call}:}{A copy of the function call that created the object.}
    \item{\code{facs}:}{A \code{list} of (possibly reordered) grouping
      factors associated with the random effects.}
    \item{\code{x}:}{If the optional argument \code{x} to
      \code{lme} is \code{TRUE}, a \code{list} of model matrices
      associated with the random effects, and the fixed effects with the
      response appended. Otherwise, an empty list.}
    \item{\code{model}:}{The model frame (of class \code{"data.frame"})
      for the model or, if the optional argument
      \code{model} to \code{lme} is \code{FALSE}, an empty frame.}
    \item{\code{REML}:}{A \code{"logical"} indicator of the model having
      been fit according to the REML criterion.}
    \item{\code{rep}:}{An \code{"ssclme"} object representing the fitted
      model.}
    \item{\code{fitted}:}{A \code{"numeric"} vector of fitted values.}
    \item{\code{residuals}:}{A \code{"numeric"} vector of raw residuals.}
  }
}
\section{Methods}{
  \describe{
    \item{VarCorr}{\code{signature(x = "lme")}: Extract the variances,
      standard deviations, and correlations of the random effects.}
    \item{anova}{\code{signature(object = "lme")}: Perform an analysis
      of variance.}
    \item{coef}{\code{signature(object = "lme")}: Extract the parameters
      that determine the relative precision matrices. The optional
      argument \code{unconst} determines if the constrained or
      unconstrained parameterization is used.}
    \item{deviance}{\code{signature(object = "lme")}: Extract the
      deviance as a numeric scalar.  The optional argument \code{REML}
      determines if the REML or ML criterion is used.}
    \item{fitted}{\code{signature(object = "lme")}: Extract the fitted
      values as a numeric vector.}
    \item{fixef}{\code{signature(object = "lme")}: Extract the fixed
      effects coefficients as a named numeric vector }
    \item{formula}{\code{signature(x = "lme")}: Extract the formula of
      the response and the fixed effects.}
    \item{logLik}{\code{signature(object = "lme")}: Extract the
      log-likelihood corresponding to the ML or REML criterion.}
    \item{plot}{\code{signature(x = "lme")}:}
    \item{ranef}{\code{signature(object = "lme")}: Extact the random
      effects as a named list of numeric matrices.}
    \item{residuals}{\code{signature(object = "lme")}: Extract the
      residuals as a numeric vector.}
    \item{show}{\code{signature(object = "lme")}: Print a concise
      description of the object.}
    \item{summary}{\code{signature(object = "lme")}: Create a summary
      object of class \code{"summary.lme"}.}
    \item{update}{\code{signature(object = "lme")}: Create an updated
      fitted model.}
    \item{vcov}{\code{signature(object = "lme")}: Extract the variances
      and covariances of the fixed-effects parameter estimates.}
  }
}
\details{Many methods for the \code{"lme"} class simply recall the
  generic on the \code{"rep"} component of the first argument.  Thus the
  methods actually are applied to an object of the \code{"ssclme"} class.}
\seealso{
  \code{\link{lme}}, \code{\link[Matrix]{ssclme-class}}
}
\keyword{classes}

\eof
\name{lme}
\docType{genericFunction}
\alias{lme}
\alias{lme,ANY,ANY,formula-method}
%\alias{lme,ANY,missing,ANY-method}
\alias{lme,missing,ANY,ANY-method}
\alias{lme,formula,ANY,formula-method}
\alias{lme,formula,ANY,list-method}
\alias{lme,formula,data.frame,list-method}
\alias{lme,formula,groupedData,list-method}
\alias{lme,formula,groupedData,missing-method}
\alias{lme,missing,groupedData,ANY-method}
\title{Fit linear mixed-effects models}
\description{
  This generic function fits a linear mixed-effects model in the
  formulation described in Laird and Ware (1982) but allowing for nested
  random effects. The within-group errors are allowed to be correlated
  and/or have unequal variances. 
}
\synopsis{
lme(formula, data, random, method = c("REML", "ML"),
    control = list(), subset, weights, na.action, offset,
    model = TRUE, x = FALSE, y = FALSE, \dots)
}
\usage{
lme(formula, data, random, \dots)
}
\arguments{
  \item{formula}{a two-sided linear formula object describing the
    fixed-effects part of the model, with the response on the left of a
    \code{~} operator and the terms, separated by \code{+} operators, on
    the right.}
  \item{data}{an optional data frame containing the variables named in
    \code{formula}, \code{random}, \code{correlation}, \code{weights}, and
    \code{subset}.  By default the variables are taken from the
    environment from which \code{lme} is called.}
 \item{random}{optionally, any of the following: (i) a one-sided formula
   of the form \code{~x1+...+xn | g1/.../gm}, with \code{x1+...+xn}
   specifying the model for the random effects and \code{g1/.../gm} the
   grouping structure (\code{m} may be equal to 1, in which case no
   \code{/} is required). The random effects formula will be repeated
   for all levels of grouping, in the case of multiple levels of
   grouping; (ii) a list of one-sided formulas of the form
   \code{~x1+...+xn | g}, with possibly different random effects models
   for each grouping factor; or (iii) a named list of formulas.}
 \item{\dots}{Optional arguments for methods.  Currently none are used.}
}
\details{
  Additional standard arguments to model-fitting functions can be passed
  to \code{lme}.
  \describe{
    \item{correlation}{an optional \code{corStruct} object describing
      the within-group correlation structure. See the documentation of
      \code{corClasses} for a description of the available \code{corStruct}
      classes. Defaults to \code{NULL}, corresponding to no within-group
      correlations.} 
    \item{weights}{an optional \code{varFunc} object or one-sided formula
      describing the within-group heteroscedasticity structure. If given as
      a formula, it is used as the argument to \code{varFixed},
      corresponding to fixed variance weights. See the documentation on
      \code{varClasses} for a description of the available \code{varFunc}
      classes. Defaults to \code{NULL}, corresponding to homocesdatic
      within-group errors.} 
    \item{subset}{an optional expression indicating the subset of the rows of
      \code{data} that should be used in the fit. This can be a logical
      vector, or a numeric vector indicating which observation numbers are
      to be included, or a  character  vector of the row names to be
      included.  All observations are included by default.}
    \item{method}{a character string.  If \code{"REML"} the model is fit by
      maximizing the restricted log-likelihood.  If \code{"ML"} the
      log-likelihood is maximized.  Defaults to \code{"REML"}.}
    \item{na.action}{a function that indicates what should happen when the
      data contain \code{NA}s.  The default action (\code{na.fail}) causes
      \code{lme} to print an error message and terminate if there are any
      incomplete observations.}
    \item{control}{a list of control values for the estimation algorithm to
      replace the default values returned by the function \code{lmeControl}.
      Defaults to an empty list.}
    \item{model, x}{logicals.  If \code{TRUE} the corresponding
      components of the fit (the model frame, the model matrices)
      are returned.}
  }
}
\value{
  An \code{\link{lme-class}{lme}} object.
}
%\references{ ~put references to the literature/web site here ~ }
%\author{}
%\note{}
\seealso{\code{\link{lme-class}}, \code{\link[stats]{lm}}}
\examples{
data(bdf)
fm <- lme(langPOST ~ IQ.ver.cen + avg.IQ.ver.cen, data = bdf,
          random = ~ IQ.ver.cen | schoolNR)
summary(fm)
}
\keyword{models}
\keyword{methods}

\eof
% $Id: lmeControl.Rd,v 1.5 2003/09/20 11:54:43 saikat Exp $
\name{lmeControl}
\alias{lmeControl}
\title{Control values for lme}
\description{
  The values supplied in the function call replace the defaults and a
  list with all possible arguments is returned. The returned list is
  used as the \code{control} argument in the \code{lme} function.
}
\synopsis{
lmeControl(maxIter = 50,
           msMaxIter = 50,
           tolerance = sqrt((.Machine$double.eps)),
           niterEM = 20,
           msTol = sqrt(.Machine$double.eps),
           msScale,
           msVerbose = getOption("verbose"),
           PQLmaxIt = 20,
           .relStep = (.Machine$double.eps)^(1/3), 
           nlmStepMax = NULL,
           optimizer="nlm",
           EMverbose = getOption("verbose"),
           analyticGradient = TRUE,
           analyticHessian=FALSE))
}
\usage{
lmeControl(maxIter, msMaxIter, tolerance, niterEM, msTol,
           msScale, msVerbose, PQLmaxIt, .relStep,
           nlmStepMax, optimizer,
           EMverbose, analyticGradient, analyticHessian)
}
\arguments{
 \item{maxIter}{maximum number of iterations for the \code{lme}
   optimization algorithm. Default is 50.} 
 \item{msMaxIter}{maximum number of iterations
   for the \code{nlm} optimization step inside the \code{lme}
   optimization. Default is 50.}
 \item{tolerance}{tolerance for the convergence criterion in the
   \code{lme} algorithm. Default is 1e-6.}
 \item{niterEM}{number of iterations for the EM algorithm used to refine
   the initial estimates of the random effects variance-covariance
   coefficients. Default is 25.}
 \item{msTol}{tolerance for the convergence criterion in \code{nlm},
   passed as the \code{rel.tolerance} argument to the function (see
   documentation on \code{nlm}). Default is 1e-7. }
 \item{msScale}{scale function passed as the \code{scale} argument to
   the \code{nlm} function (see documentation on that function). Default
   is \code{lmeScale}.}
 \item{msVerbose}{a logical value passed as the \code{trace} argument to
   \code{nlm} (see documentation on that function). Default is
   \code{getOption("verbose")}.} 
 \item{PQLmaxIt}{maximum number of iterations for the PQL algorithm in
   \code{GLMM}.}
 \item{.relStep}{relative step for numerical derivatives
   calculations. Default is \code{.Machine$double.eps^(1/3)}.}
 \item{nlmStepMax}{stepmax value to be passed to nlm. See
     \code{\link{nlm}} for details. Default is 100.0}
 \item{optimizer}{the optimizer to be used - either \code{"optim"}, the
   default, or \code{"nlm"}}
 \item{EMverbose}{a logical value indicating if verbose output should be
   produced during the EM iterations.  Default is \code{getOption("verbose"}.}
 \item{analyticGradient}{a logical value indicating if the analytic
   gradient of the objective should be used.  This option is for testing
   purposes and would not normally be changed from the default.  Default
   is \code{TRUE}.}
 \item{analyticHessian}{a logical value indicating if the analytic
   hessian of the objective should be calculated. This is an
   experimental feature and at present the default is \code{FALSE}. In
   future we may use the analytic Hessian in the optimization.}
}
\value{
  a list with a component for each of the possible arguments.
}
\seealso{\code{\link{lme}}, \code{\link{nlm}}, \code{\link{optim}},
  \code{\link{lmeScale}}, \code{\link{GLMM}}}
\examples{
# decrease the maximum number iterations in the ms call and
# request that information on the evolution of the ms iterations be printed
str(lmeControl(msMaxIter = 20, msVerbose = TRUE))
}
\keyword{models}

\eof
% $Id: pooledSD.Rd,v 1.2 2003/11/01 04:13:19 deepayan Exp $
\name{pooledSD}
\title{Extract pooled standard deviation}
\usage{
pooledSD(object)
}
\alias{pooledSD}
\arguments{
 \item{object}{an object inheriting from class \code{lmList}.}
}
\description{
  The pooled estimated standard deviation is obtained by adding together
  the residual sum of squares for each non-null element of
  \code{object}, dividing by the sum of the corresponding residual
  degrees-of-freedom, and taking the square-root.
}
\value{
  the pooled standard deviation for the non-null elements of
  \code{object}, with an attribute \code{df} with the number of
  degrees-of-freedom used in the estimation.
}
%\author{Jose Pinheiro \email{Jose.Pinheiro@pharma.novartis.com} and Douglas Bates \email{bates@stat.wisc.edu}}
\seealso{\code{\link{lmList}}, \code{\link{lm}}}
\examples{
data(Orthodont)
fm <- lmList(distance ~ age | Subject, Orthodont)
pooledSD(fm)
}
\keyword{models}

\eof
% $Id: random.effects.Rd,v 1.1 2002/11/27 22:49:45 bates Exp $
\name{random.effects}
\docType{genericFunction}
\docType{methods}
\title{Extract Random Effects}
\alias{random.effects}
\alias{ranef}
\alias{ranef-methods}
\alias{ranef,ANY-method}
\alias{ranef,reStruct-method}
\usage{
random.effects(object, \dots)
ranef(object, \dots)
}
\description{
  A generic function to extract the random effects.
}
\arguments{
 \item{object}{an object of a class from which random effects
   estimates can be extracted.}
 \item{\dots}{some methods for this generic function require additional
   arguments.}
}
\value{
  a list of matrices.
}
%\seealso{}
\examples{
## see the method function documentation
}
\keyword{models}
\keyword{methods}

\eof
\name{s3bbx}
\alias{s3bbx}
\non_function{}
\title{Covariates in the Rodriguez and Goldman simulation}
\usage{data(s3bbx)}
\description{
The \code{s3bbx} data frame has 2449 rows and 6 columns of the
covariates in the simulation by Rodriguez and Goldman of multilevel
dichotomous data.
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{child}{a numeric vector identifying the child}
    \item{family}{a numeric vector identifying the family}
    \item{community}{a numeric vector identifying the community}
    \item{chldcov}{a numeric vector of the child-level covariate}
    \item{famcov}{a numeric vector of the family-level covariate}
    \item{commcov}{a numeric vector of the community-level covariate}
  }
}
\source{
  \url{http://data.princeton.edu/multilevel/simul.htm}
}
\references{
  Rodriguez, Germn and Goldman, Noreen (1995), "An assessment of
  estimation procedures for multilevel models with binary responses",
  \emph{Journal of the Royal Statistical Society, Series A}, \bold{158},
  73-89.
}
\examples{
data(s3bbx)
str(s3bbx)
}
\keyword{datasets}

\eof
\name{s3bby}
\alias{s3bby}
\non_function{}
\title{Responses simulated by Rodriguez and Goldman}
\description{
  A matrix of the results of 100 simulations of dichotomous multilevel
  data. The rows correspond to the 2449 births for which the covariates
  are given in \code{\link{s3bbx}}.  The elements of the matrix are all
  0, indicating no modern prenatal care, or 1, indicating model prenatal
  care.  These were simulated with "large" variances for both the family
  and the community random effects.
}
\usage{data(s3bby)}
\format{
  An integer matrix with 2449 rows and 100 columns.
}
\source{
  \url{http://data.princeton.edu/multilevel/simul.htm}
}
\references{
  Rodriguez, Germn and Goldman, Noreen (1995), "An assessment of
  estimation procedures for multilevel models with binary responses",
  \emph{Journal of the Royal Statistical Society, Series A}, \bold{158},
  73-89.
}
\examples{
data(s3bby)
str(s3bby)
}
\keyword{datasets}

\eof
\name{summary.GLMM-class}
\docType{class}
\alias{summary.GLMM-class}
\alias{show,summary.GLMM-method}
\title{Class "summary.GLMM"}
\description{A summary of an \code{"GLMM"} fitted model object.}
\section{Objects from the Class}{
  Objects are created by applying the \code{summary} generic to an
  \code{"GLMM"} object.
}
\section{Slots}{
  \describe{
    \item{\code{family}:}{The family of functions
      defining the generalized linear model.  See
      \code{\link[stats]{family}} for details.}
    \item{\code{call}:}{A copy of the function call that created the
      \code{"GLMM"} object.}
    \item{\code{logLik}:}{A \code{"logLik"} object for the log-likelihood.}
    \item{\code{re}:}{A \code{"summary.ssclme"} object summarizing the
      model representation.} 
    \item{\code{residuals}:}{The residuals as a \code{"numeric"} vector.}
  }
}
\section{Extends}{
Class \code{"summary.lme"}, directly.
}
\section{Methods}{
  \describe{
    \item{show}{\code{signature(object = "summary.GLMM")}: Display the object.}
  }
}
\seealso{
  \code{\link{GLMM}}, \code{\link{GLMM-class}},
  \code{\link[Matrix]{ssclme-class}}
}
\keyword{classes}

\eof
\name{summary.lme-class}
\docType{class}
\alias{summary.lme-class}
\alias{summary.ssclme-class}
\alias{coef,summary.lme-method}
\alias{coef,summary.ssclme-method}
\alias{show,summary.lme-method}
\alias{show,summary.ssclme-method}
\title{Class "summary.lme"}
\description{A summary of an \code{"lme"} fitted model object.}
\section{Objects from the Class}{
  Objects are created by applying the \code{summary} generic to an
  \code{"lme"} object.
}
\section{Slots}{
  \describe{
    \item{\code{call}:}{A copy of the function call that created the
      \code{"lme"} object.}
    \item{\code{logLik}:}{A \code{"logLik"} object for the log-likelihood.}
    \item{\code{re}:}{A \code{"summary.ssclme"} object summarizing the
      model representation.} 
    \item{\code{residuals}:}{The residuals as a \code{"numeric"} vector.}
  }
}
\section{Methods}{
  \describe{
    \item{show}{\code{signature(object = "summary.lme")}: Display the object}
  }
}
\seealso{
  \code{\link{lme-class}}, \code{\link[Matrix]{ssclme-class}}
}
\keyword{classes}

\eof
